@@ -39,8 +39,8 @@ mod_CFRunLoopObserverCallBack(
 		@encode(CFRunLoopActivity), &activity);
 
 	PyObject* result = PyObject_CallFunction(
-		PyTuple_GET_ITEM(info, 0),
-		"NNO", py_f, py_activity, PyTuple_GET_ITEM(info, 1));
+		PyTuple_GetItem(info, 0),
+		"NNO", py_f, py_activity, PyTuple_GetItem(info, 1));
 	if (result == NULL) {
 		PyObjCErr_ToObjCWithGILState(&state);
 	}
@@ -167,8 +167,8 @@ mod_CFRunLoopObserverGetContext(
 	}
 
 
-	Py_INCREF(PyTuple_GET_ITEM((PyObject*)context.info, 1));
-	return PyTuple_GET_ITEM((PyObject*)context.info, 1);
+	Py_INCREF(PyTuple_GetItem((PyObject*)context.info, 1));
+	return PyTuple_GetItem((PyObject*)context.info, 1);
 }
 
 #define COREFOUNDATION_RUNLOOP_METHODS \
