@@ -1,3 +1,12 @@
+
+#if PY_MAJOR_VERSION == 2
+#  define BYTES_ARG "s"
+
+#else
+#  define BYTES_ARG "y"
+
+#endif
+
 static PyObject* 
 call_NSCoder_encodeValueOfObjCType_at_(
 	PyObject* method, PyObject* self, PyObject* arguments)
@@ -8,9 +17,10 @@ call_NSCoder_encodeValueOfObjCType_at_(
 	int    size;
 	int err;
 	struct objc_super super;
+	Py_ssize_t typestr_len;
 
 	if  (
-		!PyArg_ParseTuple(arguments, Py_ARG_BYTES "O", &typestr, &value)) {
+		!PyArg_ParseTuple(arguments, BYTES_ARG "#O", &typestr, &typestr_len, &value)) {
 		return NULL;
 	}
 
@@ -134,7 +144,9 @@ call_NSCoder_encodeArrayOfObjCType_count_at_(
 	int    size;
 	int err;
 	struct objc_super super;
-	if  (!PyArg_ParseTuple(arguments, Py_ARG_BYTES Py_ARG_NSUInteger "O", &typestr, &count, &value)) {
+	Py_ssize_t typestr_len;
+
+	if  (!PyArg_ParseTuple(arguments, BYTES_ARG "#" Py_ARG_NSUInteger "O", &typestr, &typestr_len, &count, &value)) {
 		return NULL;
 	}
 
@@ -230,16 +242,16 @@ imp_NSCoder_encodeArrayOfObjCType_count_at_(
 
 	pyself = PyObjCObject_NewTransient(self, &cookie);
 	if (pyself == NULL) goto error;
-	PyTuple_SET_ITEM(arglist, 0, pyself);
+	PyTuple_SetItem(arglist, 0, pyself);
 	Py_INCREF(pyself);
 
 	v = PyBytes_FromString(typestr);
 	if (v == NULL) goto error;
-	PyTuple_SET_ITEM(arglist, 1, v);
+	PyTuple_SetItem(arglist, 1, v);
 
 	v = PyInt_FromLong(count);
 	if (v == NULL) goto error;
-	PyTuple_SET_ITEM(arglist, 2, v);
+	PyTuple_SetItem(arglist, 2, v);
 
 	values = PyTuple_New(count);
 	if (values == NULL) goto error;
@@ -247,9 +259,9 @@ imp_NSCoder_encodeArrayOfObjCType_count_at_(
 	for (i = 0; i < count; i++) {
 		v = PyObjC_ObjCToPython(typestr, ((char*)buf)+(i*size));
 		if (v == NULL) goto error;
-		PyTuple_SET_ITEM(values, i, v);
+		PyTuple_SetItem(values, i, v);
 	}
-	PyTuple_SET_ITEM(arglist, 3, values);
+	PyTuple_SetItem(arglist, 3, values);
 	values = NULL;
 
 	result = PyObject_Call((PyObject*)callable, arglist, NULL);
@@ -283,11 +295,11 @@ call_NSCoder_decodeValueOfObjCType_at_(
 	char* typestr;
 	PyObject* value;
 	void*     buf;
-	Py_ssize_t    size;
+	Py_ssize_t    size, typestr_len;
 	struct objc_super super;
 	PyObject* py_buf;
 
-	if  (!PyArg_ParseTuple(arguments, Py_ARG_BYTES "O", &typestr, &py_buf)) {
+	if  (!PyArg_ParseTuple(arguments, BYTES_ARG "#O", &typestr, &typestr_len, &py_buf)) {
 		return NULL;
 	}
 
@@ -406,7 +418,9 @@ call_NSCoder_decodeArrayOfObjCType_count_at_(
 	void*     buf;
 	int    size;
 	struct objc_super super;
-	if  (!PyArg_ParseTuple(arguments, Py_ARG_BYTES Py_ARG_NSUInteger "O", &typestr, &count, &py_buf)) {
+	Py_ssize_t typestr_len;
+
+	if  (!PyArg_ParseTuple(arguments, BYTES_ARG "#" Py_ARG_NSUInteger "O", &typestr, &typestr_len, &count, &py_buf)) {
 		return NULL;
 	}
 
@@ -457,9 +471,9 @@ call_NSCoder_decodeArrayOfObjCType_count_at_(
 	}
 
 	for (i = 0; i < count; i++) {
-		PyTuple_SET_ITEM(result, i,  PyObjC_ObjCToPython(typestr, 
+		PyTuple_SetItem(result, i,  PyObjC_ObjCToPython(typestr, 
 				((char*)buf) + (size * i)));
-		if (PyTuple_GET_ITEM(result, i) == NULL) {
+		if (PyTuple_GetItem(result, i) == NULL) {
 			Py_DECREF(result);
 			PyMem_Free(buf);
 			return NULL;
@@ -561,12 +575,13 @@ call_NSCoder_encodeBytes_length_(
 
 	struct objc_super super;
 
-	if  (!PyArg_ParseTuple(arguments, "t#"Py_ARG_SIZE_T, &bytes, &size, &length)) {
+	if  (!PyArg_ParseTuple(arguments, BYTES_ARG"#"Py_ARG_SIZE_T, &bytes, &size, &length)) {
 		return NULL;
 	}
 
 	if (length > size) {
-		PyErr_SetString(PyExc_ValueError, "length > len(buf)");
+		PyErr_Format(PyExc_ValueError, "length %" PY_FORMAT_SIZE_T "d > len(buf) %" PY_FORMAT_SIZE_T "d",
+			length, size);
 		return NULL;
 	}
 
@@ -704,7 +719,7 @@ call_NSCoder_decodeBytesWithReturnedLength_(
 			return NULL;
 		}
 
-		PyTuple_SET_ITEM(result, 0, Py_None);
+		PyTuple_SetItem(result, 0, Py_None);
 		Py_INCREF(Py_None);
 
 		v = PyObjC_ObjCToPython(@encode(unsigned), &size);
@@ -712,7 +727,7 @@ call_NSCoder_decodeBytesWithReturnedLength_(
 			Py_DECREF(result);
 			return NULL;
 		}
-		PyTuple_SET_ITEM(result, 1, v);
+		PyTuple_SetItem(result, 1, v);
 		return result;
 	}
 
@@ -727,14 +742,14 @@ call_NSCoder_decodeBytesWithReturnedLength_(
 		return NULL;
 	}
 
-	PyTuple_SET_ITEM(result, 0, v);
+	PyTuple_SetItem(result, 0, v);
 
 	v = PyObjC_ObjCToPython(@encode(unsigned), &size);
 	if (v == NULL) {
 		Py_DECREF(result);
 		return NULL;
 	}
-	PyTuple_SET_ITEM(result, 1, v);
+	PyTuple_SetItem(result, 1, v);
 
 	return result;
 }
@@ -781,7 +796,7 @@ imp_NSCoder_decodeBytesWithReturnedLength_(
 	}
 
 	if (PyObject_AsReadBuffer(
-			PyTuple_GET_ITEM(result, 0), 
+			PyTuple_GetItem(result, 0), 
 			pretval, &buflen) < 0) {
 		
 		Py_DECREF(result);
@@ -789,7 +804,7 @@ imp_NSCoder_decodeBytesWithReturnedLength_(
 	}
 	
 	if (PyObjC_PythonToObjC(@encode(NSUInteger), 
-			PyTuple_GET_ITEM(result, 1), &len) < 0) {
+			PyTuple_GetItem(result, 1), &len) < 0) {
 		Py_DECREF(result);
 		goto error;
 	}
@@ -874,7 +889,7 @@ call_NSCoder_decodeBytesForKey_returnedLength_(
 			return NULL;
 		}
 
-		PyTuple_SET_ITEM(result, 0, Py_None);
+		PyTuple_SetItem(result, 0, Py_None);
 		Py_INCREF(Py_None);
 
 		v = PyObjC_ObjCToPython(@encode(unsigned), &size);
@@ -882,7 +897,7 @@ call_NSCoder_decodeBytesForKey_returnedLength_(
 			Py_DECREF(result);
 			return NULL;
 		}
-		PyTuple_SET_ITEM(result, 1, v);
+		PyTuple_SetItem(result, 1, v);
 		return result;
 	}
 
@@ -897,14 +912,14 @@ call_NSCoder_decodeBytesForKey_returnedLength_(
 		return NULL;
 	}
 
-	PyTuple_SET_ITEM(result, 0, v);
+	PyTuple_SetItem(result, 0, v);
 
 	v = PyObjC_ObjCToPython(@encode(NSUInteger), &size);
 	if (v == NULL) {
 		Py_DECREF(result);
 		return NULL;
 	}
-	PyTuple_SET_ITEM(result, 1, v);
+	PyTuple_SetItem(result, 1, v);
 
 	return result;
 }
@@ -956,7 +971,7 @@ imp_NSCoder_decodeBytesForKey_returnedLength_(
 	}
 
 	if (PyObject_AsReadBuffer(
-			PyTuple_GET_ITEM(result, 0), 
+			PyTuple_GetItem(result, 0), 
 			pretval, &buflen) < 0) {
 		
 		Py_DECREF(result);
@@ -964,7 +979,7 @@ imp_NSCoder_decodeBytesForKey_returnedLength_(
 	}
 	
 	if (PyObjC_PythonToObjC(@encode(NSUInteger), 
-			PyTuple_GET_ITEM(result, 1), &len) < 0) {
+			PyTuple_GetItem(result, 1), &len) < 0) {
 		Py_DECREF(result);
 		goto error;
 	}
@@ -1006,7 +1021,7 @@ call_NSCoder_encodeBytes_length_forKey_(
 	id     		key;
 	struct objc_super super;
 
-	if  (!PyArg_ParseTuple(arguments, "t#O&", &bytes, &size, 
+	if  (!PyArg_ParseTuple(arguments, BYTES_ARG "#O&", &bytes, &size, 
 			PyObjCObject_Convert, &key)) {
 		return NULL;
 	}
