@@ -8,14 +8,14 @@ class TestAlertFormat (TestCase):
     def testSimple(self):
         alert = NSAlert.alertWithMessageText_defaultButton_alternateButton_otherButton_informativeTextWithFormat_(
                 "message text", "ok", "cancel", "help", "foobar is the sucks")
-        self.assertEquals(alert.messageText(), "message text")
-        self.assertEquals(alert.informativeText(), "foobar is the sucks")
+        self.assertEqual(alert.messageText(), "message text")
+        self.assertEqual(alert.informativeText(), "foobar is the sucks")
 
     def testWithFormat(self):
         alert = NSAlert.alertWithMessageText_defaultButton_alternateButton_otherButton_informativeTextWithFormat_(
                 "message text", "ok", "cancel", "help", "%d * %d = %d", 9, 7, 9*7)
-        self.assertEquals(alert.messageText(), "message text")
-        self.assertEquals(alert.informativeText(), "9 * 7 = 63")
+        self.assertEqual(alert.messageText(), "message text")
+        self.assertEqual(alert.informativeText(), "9 * 7 = 63")
 
 if __name__ == "__main__":
     main()
