@@ -2,8 +2,31 @@ from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 import CoreFoundation
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 
 class TestBase (TestCase):
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertEqual(kCFCoreFoundationVersionNumber10_6_6, 550.42)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_6_7, 550.42)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_6_8, 550.43)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_7, 635.00)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_7_1, 635.00)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_7_2, 635.15)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_7_3, 635.19)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_7_4, 635.21)
+
+
     def testConstants(self):
         self.assertEqual(TRUE, 1)
         self.assertEqual(FALSE, 0)
@@ -49,6 +72,23 @@ class TestBase (TestCase):
         self.assertEqual(kCFCoreFoundationVersionNumber10_4_9,    368.28)
         self.assertEqual(kCFCoreFoundationVersionNumber10_4_10,   368.28)
         self.assertEqual(kCFCoreFoundationVersionNumber10_4_11,   368.31)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_5,      476.00)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_5_1,    476.00)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_5_2,    476.10)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_5_3,    476.13)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_5_4,    476.14)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_5_5,    476.15)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_5_6,    476.17)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_5_7,    476.18)
+        #XXX
+        #self.assertEqual(CFCoreFoundationVersionNumber10_5_8,    476.19)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_6,      550.00)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_6_1,    550.00)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_6_2,    550.13)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_6_3,    550.19)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_6_4,    550.29)
+        self.assertEqual(kCFCoreFoundationVersionNumber10_6_5,    550.42)
+
 
         self.assertEqual(kCFCompareLessThan, -1)
         self.assertEqual(kCFCompareEqualTo, 0)
@@ -101,13 +141,14 @@ class TestBase (TestCase):
         r = CFAllocatorGetPreferredSizeForSize(kCFAllocatorDefault, 15, 0)
         self.assertIsInstance(r, (int, long))
         self.assertGreaterEqual(r , 15)
+
     def testGenericFunctions(self):
         id = CFGetTypeID(kCFAllocatorMalloc)
         self.assertEqual(id, CFAllocatorGetTypeID())
 
         v = CFCopyTypeIDDescription(CFAllocatorGetTypeID())
         self.assertIsInstance(v, unicode)
-        obj = CFURLCreateWithString(None, u"http://www.apple.com/", None)
+        obj = CFURLCreateWithString(None, b"http://www.apple.com/".decode('ascii'), None)
         i = CFGetRetainCount(obj)
         self.assertIsInstance(i, (int, long))
         CFRetain(obj)
