@@ -1,7 +1,19 @@
 from CoreFoundation import *
 from PyObjCTools.TestSupport import *
+import Foundation
 
 
+try:
+    long
+except NameError:
+    long = int
+
+
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestCFBundle (TestCase):
 
     def testTypes(self):
@@ -10,38 +22,39 @@ class TestCFBundle (TestCase):
     def testMainBundle(self):
         bundle = CFBundleGetMainBundle()
         self.assertIsInstance(bundle, CFBundleRef)
+
     def testBundleLoader(self):
-        bundle = CFBundleGetBundleWithIdentifier(u"com.apple.CoreFoundation")
+        bundle = CFBundleGetBundleWithIdentifier(b"com.apple.CoreFoundation".decode('ascii'))
         self.assertIsInstance(bundle, CFBundleRef)
         array = list(CFBundleGetAllBundles())
         self.assertNotEqual(len(array) , 0)
         for b in array:
             self.assertIsInstance(b, CFBundleRef)
-        url = CFURLCreateWithFileSystemPath(None, u"/System/Library/Frameworks/Foundation.framework", kCFURLPOSIXPathStyle, True)
+        url = CFURLCreateWithFileSystemPath(None, 
+                b"/System/Library/Frameworks/Foundation.framework".decode('ascii'), kCFURLPOSIXPathStyle, True)
         bundle = CFBundleCreate(None, url)
         self.assertIsInstance(bundle, CFBundleRef)
-        url = CFURLCreateWithFileSystemPath(None, u"/System/Library/Frameworks", kCFURLPOSIXPathStyle, True)
-        array = CFBundleCreateBundlesFromDirectory(None, url, u"frameworkX")
+        url = CFURLCreateWithFileSystemPath(None, b"/System/Library/Frameworks".decode('ascii'), kCFURLPOSIXPathStyle, True)
+        array = CFBundleCreateBundlesFromDirectory(None, url, b"frameworkX".decode('ascii'))
         self.assertEqual(len(array), 0)
 
-        array = CFBundleCreateBundlesFromDirectory(None, url, u"framework")
+        array = CFBundleCreateBundlesFromDirectory(None, url, b"framework".decode('ascii'))
         self.assertNotEquals(len(array), 0)
 
         array = CFBundleCreateBundlesFromDirectory(None, url, None)
         self.assertNotEquals(len(array), 0)
 
-
-
     def testTypeID(self):
         v = CFBundleGetTypeID()
         self.assertIsInstance(v, (int, long))
+
     def testInspection(self):
-        bundle = CFBundleGetBundleWithIdentifier(u"com.apple.CoreFoundation")
+        bundle = CFBundleGetBundleWithIdentifier(b"com.apple.CoreFoundation".decode('ascii'))
         self.assertIsInstance(bundle, CFBundleRef)
         url = CFBundleCopyBundleURL(bundle)
         self.assertIsInstance(url, CFURLRef)
-        v = CFBundleGetValueForInfoDictionaryKey(bundle, u"CFBundleIdentifier")
-        self.assertEqual(v , u"com.apple.CoreFoundation")
+        v = CFBundleGetValueForInfoDictionaryKey(bundle, b"CFBundleIdentifier".decode('ascii'))
+        self.assertEqual(v , b"com.apple.CoreFoundation".decode('ascii'))
         v = CFBundleGetInfoDictionary(bundle)
         self.assertIsInstance(v, CFDictionaryRef)
         self.assertTrue( v['CFBundleIdentifier'], 'com.apple.CoreFoundation')
@@ -53,7 +66,7 @@ class TestCFBundle (TestCase):
         self.assertIsInstance(type, (int, long))
         self.assertIsInstance(creator, (int, long))
         identifier = CFBundleGetIdentifier(bundle)
-        self.assertEqual(identifier , u'com.apple.CoreFoundation')
+        self.assertEqual(identifier , b"com.apple.CoreFoundation".decode('ascii'))
         v = CFBundleGetVersionNumber(bundle)
         self.assertIsInstance(v, (int, long))
         v = CFBundleGetDevelopmentRegion(bundle)
@@ -78,26 +91,29 @@ class TestCFBundle (TestCase):
             self.assertIsInstance(v, CFURLRef)
 
     def testDirectAccess(self):
-        url = CFURLCreateWithFileSystemPath(None, u"/System/Library/Frameworks/Foundation.framework", kCFURLPOSIXPathStyle, True)
+        url = CFURLCreateWithFileSystemPath(None, 
+                b"/System/Library/Frameworks/Foundation.framework".decode('ascii'), kCFURLPOSIXPathStyle, True)
 
         v = CFBundleCopyInfoDictionaryInDirectory(url)
         self.assertIsInstance(v, CFDictionaryRef)
-        self.assertEqual(v[u"CFBundleIdentifier"] , u"com.apple.Foundation")
+        self.assertEqual(v[b"CFBundleIdentifier".decode('ascii')] , b"com.apple.Foundation".decode('ascii'))
         ok, type, creator = CFBundleGetPackageInfoInDirectory(url, None, None)
         self.assertIs(ok, True)
         self.assertIsInstance(type, (int, long))
         self.assertIsInstance(creator, (int, long))
 
     def testResources(self):
-        url = CFURLCreateWithFileSystemPath(None, u"/System/Library/Frameworks/Foundation.framework", kCFURLPOSIXPathStyle, True)
+        url = CFURLCreateWithFileSystemPath(None, 
+                b"/System/Library/Frameworks/Foundation.framework".decode('ascii'), kCFURLPOSIXPathStyle, True)
         bundle = CFBundleCreate(None, url)
         self.assertIsInstance(bundle, CFBundleRef)
-        url = CFURLCreateWithFileSystemPath(None, u"/System/Library/Frameworks/Tcl.framework", kCFURLPOSIXPathStyle, True)
+        url = CFURLCreateWithFileSystemPath(None, 
+                b"/System/Library/Frameworks/Tcl.framework".decode('ascii'), kCFURLPOSIXPathStyle, True)
         bundle2 = CFBundleCreate(None, url)
         self.assertIsInstance(bundle2, CFBundleRef)
         url = CFBundleCopyResourceURL(bundle, "Formatter", "strings", None)
         self.assertIsInstance(url, CFURLRef)
-        url = CFBundleCopyResourceURL(bundle, "Formatter", "strings", "dummy")
+        url = CFBundleCopyResourceURL(bundle, "Formatter", "strings", "helloworld.lproj")
         self.assertIs(url, None)
         array = CFBundleCopyResourceURLsOfType(bundle, "strings", None)
         self.assertIsNot(array, None)
@@ -122,6 +138,8 @@ class TestCFBundle (TestCase):
         url = CFBundleCopyResourceURLForLocalization(bundle, "Formatter", "strings", None, "Dutch");
         if url is None:
             url = CFBundleCopyResourceURLForLocalization(bundle, "Formatter", "strings", None, "nl");
+        if url is None:
+            url = CFBundleCopyResourceURLForLocalization(bundle, "Formatter", "strings", None, "en");
         self.assertIsInstance(url, CFURLRef)
 
         array = CFBundleCopyResourceURLsOfTypeForLocalization(bundle, "strings", None, "Dutch")
@@ -202,7 +220,8 @@ class TestCFBundle (TestCase):
             CFBundleCloseBundleResourceMap(bundle, id2)
 
     def testResourcesDirect(self):
-        bundle = CFURLCreateWithFileSystemPath(None, u"/System/Library/Frameworks/Foundation.framework", kCFURLPOSIXPathStyle, True)
+        bundle = CFURLCreateWithFileSystemPath(None, 
+                b"/System/Library/Frameworks/Foundation.framework".decode('ascii'), kCFURLPOSIXPathStyle, True)
         url = CFBundleCopyResourceURLInDirectory(bundle, "Formatter", "strings", None)
         self.assertIsInstance(url, CFURLRef)
         array = CFBundleCopyResourceURLsOfTypeInDirectory(bundle, "strings", None)
@@ -216,12 +235,15 @@ class TestCFBundle (TestCase):
         self.assertIsInstance(array, CFArrayRef)
         for a in array:
             self.assertIsInstance(a, (int, long))
+
     def testPlugin(self):
-        url = CFURLCreateWithFileSystemPath(None, u"/System/Library/Components/AppleScript.component", kCFURLPOSIXPathStyle, True)
+        url = CFURLCreateWithFileSystemPath(None, 
+                b"/System/Library/Components/AppleScript.component".decode('ascii'), kCFURLPOSIXPathStyle, True)
         bundle = CFBundleCreate(None, url)
         self.assertIsInstance(bundle, CFBundleRef)
         ref = CFBundleGetPlugIn(bundle)
         self.assertIs(ref, None)
+
     def testConstants(self):
         self.assertIsInstance(kCFBundleInfoDictionaryVersionKey, unicode)
         self.assertIsInstance(kCFBundleExecutableKey, unicode)
@@ -234,5 +256,6 @@ class TestCFBundle (TestCase):
         self.assertEqual(kCFBundleExecutableArchitecturePPC      , 0x00000012)
         self.assertEqual(kCFBundleExecutableArchitectureX86_64   , 0x01000007)
         self.assertEqual(kCFBundleExecutableArchitecturePPC64    , 0x01000012)
+
 if __name__ == "__main__":
     main()
