@@ -2,6 +2,12 @@ from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 import datetime
 
+try:
+    long
+except NameError:
+    long = int
+
+
 class TestCFCalendarVariadic (TestCase):
     def testTypes(self):
         self.assertIsCFType(CFCalendarRef)
@@ -42,7 +48,6 @@ class TestCFCalendarVariadic (TestCase):
         self.assertEqual(y, 2)
         self.assertEqual(H, 3)
 
-
     def testCFCalendarDecomposeAbsoluteTime(self):
         calendar = CFCalendarCreateWithIdentifier(
                 None, kCFGregorianCalendar)
@@ -127,7 +132,6 @@ class TestCFCalendarVariadic (TestCase):
         self.assertEqual(rng.location, 1)
         self.assertEqual(rng.length, monthLength)
 
-
         v = CFCalendarGetOrdinalityOfUnit(cal, kCFCalendarUnitDay, kCFCalendarUnitYear, CFAbsoluteTimeGetCurrent())
         self.assertIsInstance(v, (int, long))
         ok, startp, tip = CFCalendarGetTimeRangeOfUnit(cal, kCFCalendarUnitDay, CFAbsoluteTimeGetCurrent(), None, None)
@@ -139,7 +143,7 @@ class TestCFCalendarVariadic (TestCase):
     def testMutation(self):
         cal = CFCalendarCreateWithIdentifier(None, kCFBuddhistCalendar)
 
-        loc = CFLocaleCreate(None, u"mr_IN")
+        loc = CFLocaleCreate(None, b"mr_IN".decode('latin1'))
         self.assertIsInstance(loc, CFLocaleRef)
         id1 = CFLocaleGetIdentifier(loc)
 
@@ -153,14 +157,14 @@ class TestCFCalendarVariadic (TestCase):
 
         self.assertEqual(new_id , id1)
         self.assertNotEqual(orig_id , id1)
-        tz = CFTimeZoneCreateWithName(None, u"Pacific/Wallis", True)
+        tz = CFTimeZoneCreateWithName(None, b"Pacific/Wallis".decode('latin1'), True)
         self.assertIsInstance(tz, CFTimeZoneRef)
         orig_zone = CFCalendarCopyTimeZone(cal)
         self.assertIsInstance(orig_zone, CFTimeZoneRef)
         CFCalendarSetTimeZone(cal, tz)
         new_zone = CFCalendarCopyTimeZone(cal)
         self.assertIsInstance(new_zone, CFTimeZoneRef)
-        self.assertEqual(CFTimeZoneGetName(new_zone) , u'Pacific/Wallis' )
+        self.assertEqual(CFTimeZoneGetName(new_zone) , b'Pacific/Wallis'.decode('latin1') )
         weekday = CFCalendarGetFirstWeekday(cal)
         weekday = weekday + 2 % 7
         CFCalendarSetFirstWeekday(cal, weekday)
@@ -193,6 +197,12 @@ class TestCFCalendarVariadic (TestCase):
     def testConstants10_6(self):
         self.assertEqual(kCFCalendarUnitQuarter, 1<<11)
 
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertEqual(kCFCalendarUnitWeekOfMonth, 1<<12)
+        self.assertEqual(kCFCalendarUnitWeekOfYear, 1<<13)
+        self.assertEqual(kCFCalendarUnitYearForWeekOfYear, 1<<14)
+
 
 if __name__ == "__main__":
     main()
