@@ -2,9 +2,21 @@ from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestDateFormatter (TestCase):
     def testTypeID(self):
         self.assertIsInstance(CFDateGetTypeID(), (int, long))
+
     def testConstants(self):
         self.assertEqual(kCFDateFormatterNoStyle , 0)
         self.assertEqual(kCFDateFormatterShortStyle , 1)
@@ -37,8 +49,8 @@ class TestDateFormatter (TestCase):
         self.assertIsInstance(kCFDateFormatterQuarterSymbols, unicode)
         self.assertIsInstance(kCFDateFormatterShortQuarterSymbols, unicode)
         self.assertIsInstance(kCFDateFormatterStandaloneQuarterSymbols, unicode)
-        self.assertIsInstance( kCFDateFormatterShortStandaloneQuarterSymbols, unicode)
-        self.assertIsInstance( kCFDateFormatterGregorianStartDate, unicode)
+        self.assertIsInstance(kCFDateFormatterShortStandaloneQuarterSymbols, unicode)
+        self.assertIsInstance(kCFDateFormatterGregorianStartDate, unicode)
 
     @min_os_level('10.6')
     def testConstants10_6(self):
@@ -50,17 +62,17 @@ class TestDateFormatter (TestCase):
         r = CFDateFormatterCreateDateFormatFromTemplate(None, "%Y-%m-%d", 0, None)
         self.assertIsInstance(r, unicode)
                             
-
-
     def testTypes(self):
         self.assertIsCFType(CFDateFormatterRef)
 
+        self.assertIsInstance(CFDateFormatterGetTypeID(), (int, long))
+
     def testInspection(self):
         locale = CFLocaleCopyCurrent()
         self.assertIsInstance(locale, CFLocaleRef)
 
         date = CFDateCreate(None, CFAbsoluteTimeGetCurrent())
-        self.assertIsInstance(date, CFDateRef)
+        self.assertIsInstance(date, NSDate)
 
         self.assertResultIsCFRetained(CFDateFormatterCreate)
         fmt = CFDateFormatterCreate(None, locale, kCFDateFormatterShortStyle, kCFDateFormatterLongStyle) 
@@ -85,7 +97,7 @@ class TestDateFormatter (TestCase):
         v = CFDateFormatterCreateStringWithAbsoluteTime(None, fmt, CFAbsoluteTimeGetCurrent())
         self.assertIsInstance(v, unicode)
         dt, rng = CFDateFormatterCreateDateFromString(None, fmt, v, (0, len(v)))
-        self.assertIsInstance(dt, CFDateRef)
+        self.assertIsInstance(dt, NSDate)
         self.assertIsInstance(rng, CFRange)
         ok, rng, abstime = CFDateFormatterGetAbsoluteTimeFromString(fmt, v, (0, len(v)), None)
         self.assertIs(ok, True)
@@ -94,14 +106,15 @@ class TestDateFormatter (TestCase):
         self.assertResultIsCFRetained(CFDateFormatterCopyProperty)
         v = CFDateFormatterCopyProperty(fmt, kCFDateFormatterCalendarName)
         self.assertIsInstance(v, unicode)
-        CFDateFormatterSetProperty(fmt, kCFDateFormatterCalendarName, u"gregorian")
+        CFDateFormatterSetProperty(fmt, kCFDateFormatterCalendarName, b"gregorian".decode('latin1'))
         v = CFDateFormatterCopyProperty(fmt, kCFDateFormatterCalendarName)
         self.assertIsInstance(v, unicode)
-        self.assertEqual(v , u"gregorian")
+        self.assertEqual(v , b"gregorian".decode('latin1'))
         v = CFDateFormatterCopyProperty(fmt, kCFDateFormatterIsLenient)
         self.assertTrue(v is True or v is False)
         CFDateFormatterSetProperty(fmt, kCFDateFormatterIsLenient, True)
         v2 = CFDateFormatterCopyProperty(fmt, kCFDateFormatterIsLenient)
         self.assertIs(v2, True)
+
 if __name__ == "__main__":
     main()
