@@ -5,6 +5,12 @@ FIXME: None of these tests actually use the filedescriptor
 from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 
+try:
+    long
+except NameError:
+    long = int
+
+
 
 class TestFileDescriptor (TestCase):
     def testTypes(self):
@@ -12,9 +18,11 @@ class TestFileDescriptor (TestCase):
 
     def testTypeID(self):
         self.assertIsInstance(CFFileDescriptorGetTypeID(), (int, long))
+
     def testConstants(self):
         self.assertEqual(kCFFileDescriptorReadCallBack , 1 << 0)
         self.assertEqual(kCFFileDescriptorWriteCallBack , 1 << 1)
+
     def testInspection(self):
         def callout(fd, types, context):
             pass
