@@ -2,6 +2,12 @@ from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 
 
+try:
+    long
+except NameError:
+    long = int
+
+
 class TestNotificationCenter (TestCase):
 
     def testTypes(self):
@@ -9,6 +15,7 @@ class TestNotificationCenter (TestCase):
 
     def testTypeID(self):
         self.assertIsInstance(CFNotificationCenterGetTypeID(), (int, long))
+
     def testGetting(self):
         ref = CFNotificationCenterGetLocalCenter();
         self.assertIsInstance(ref,CFNotificationCenterRef)
@@ -16,6 +23,7 @@ class TestNotificationCenter (TestCase):
         self.assertIsInstance(ref,CFNotificationCenterRef)
         ref = CFNotificationCenterGetDarwinNotifyCenter();
         self.assertIsInstance(ref,CFNotificationCenterRef)
+
     def testSending(self):
         ref = CFNotificationCenterGetLocalCenter();
         self.assertIsInstance(ref,CFNotificationCenterRef)
@@ -28,48 +36,54 @@ class TestNotificationCenter (TestCase):
         self.assertArgIsFunction(CFNotificationCenterAddObserver, 2, b'v@@@@@', True)
         self.assertArgHasType(CFNotificationCenterAddObserver, 4, b'@')
 
-        CFNotificationCenterAddObserver(ref, u"object", observe, u"pyobjc.test", ref, CFNotificationSuspensionBehaviorDeliverImmediately)
+        args = {}
+        args["object"] = b"object".decode('ascii')
+        args["pyobjc.test"] = b"pyobjc.test".decode('ascii')
 
-        CFNotificationCenterPostNotificationWithOptions(ref, u"pyobjc.test", ref, {u"name":u"value"},  kCFNotificationPostToAllSessions)
+        CFNotificationCenterAddObserver(ref, args["object"], observe, args["pyobjc.test"], ref, CFNotificationSuspensionBehaviorDeliverImmediately)
+
+        CFNotificationCenterPostNotificationWithOptions(ref, b"pyobjc.test".decode('ascii'), ref, {b"name".decode('ascii'):b"value".decode('ascii')},  kCFNotificationPostToAllSessions)
         self.assertEqual(len(notifications) , 1)
         info = notifications[-1]
         self.assertIs(info[0], ref)
-        self.assertEqual(info[1] , u"object")
-        self.assertEqual(info[2] , u"pyobjc.test")
+        self.assertEqual(info[1] , b"object".decode('ascii'))
+        self.assertEqual(info[2] , b"pyobjc.test".decode('ascii'))
         self.assertIs(info[3], ref)
-        self.assertEqual(info[4] , {u"name":u"value"})
-        CFNotificationCenterPostNotification(ref, u"pyobjc.test", ref, {u"name2":u"value2"},  True)
+        self.assertEqual(info[4] , {b"name".decode('ascii'):b"value".decode('ascii')})
+        CFNotificationCenterPostNotification(ref, b"pyobjc.test".decode('ascii'), ref, {b"name2".decode('ascii'):b"value2".decode('ascii')},  True)
         self.assertEqual(len(notifications) , 2)
         info = notifications[-1]
         self.assertIs(info[0], ref)
-        self.assertEqual(info[1] , u"object")
-        self.assertEqual(info[2] , u"pyobjc.test")
+        self.assertEqual(info[1] , b"object".decode('ascii'))
+        self.assertEqual(info[2] , b"pyobjc.test".decode('ascii'))
         self.assertIs(info[3], ref)
-        self.assertEqual(info[4] , {u"name2":u"value2"})
+        self.assertEqual(info[4] , {b"name2".decode('ascii'):b"value2".decode('ascii')})
         self.assertArgHasType(CFNotificationCenterRemoveObserver, 1, b'@')
         self.assertArgHasType(CFNotificationCenterRemoveObserver, 3, b'@')
-        CFNotificationCenterRemoveObserver(ref, u"object", u"pyobjc.test", ref)
+        CFNotificationCenterRemoveObserver(ref, args["object"], args["pyobjc.test"], ref)
 
         self.assertArgHasType(CFNotificationCenterPostNotificationWithOptions, 2, b'@') 
-        CFNotificationCenterPostNotificationWithOptions(ref, u"pyobjc.test", ref, {u"name":u"value"},  kCFNotificationPostToAllSessions)
+        CFNotificationCenterPostNotificationWithOptions(ref, b"pyobjc.test".decode('ascii'), ref, {b"name".decode('ascii'):b"value".decode('ascii')},  kCFNotificationPostToAllSessions)
         self.assertEqual(len(notifications) , 2)
-        CFNotificationCenterAddObserver(ref, u"object", observe, u"pyobjc.test", ref, CFNotificationSuspensionBehaviorDeliverImmediately)
+
+        CFNotificationCenterAddObserver(ref, args["object"], observe, args["pyobjc.test"], ref, CFNotificationSuspensionBehaviorDeliverImmediately)
 
         self.assertArgHasType(CFNotificationCenterPostNotification, 2, b'@')
         self.assertArgIsBOOL(CFNotificationCenterPostNotification, 4)
-        CFNotificationCenterPostNotification(ref, u"pyobjc.test", ref, {u"name2":u"value2"},  True)
+        CFNotificationCenterPostNotification(ref, b"pyobjc.test".decode('ascii'), ref, {b"name2".decode('ascii'):b"value2".decode('ascii')},  True)
         self.assertEqual(len(notifications) , 3)
-        CFNotificationCenterRemoveEveryObserver(ref, u"object")
-        CFNotificationCenterPostNotification(ref, u"pyobjc.test", ref, {u"name2":u"value2"},  True)
+        CFNotificationCenterRemoveEveryObserver(ref, args["object"])
+        CFNotificationCenterPostNotification(ref, b"pyobjc.test".decode('ascii'), ref, {b"name2".decode('ascii'):b"value2".decode('ascii')},  True)
         self.assertEqual(len(notifications) , 3)
+
     def testConstants(self):
         self.assertEqual(CFNotificationSuspensionBehaviorDrop, 1)
         self.assertEqual(CFNotificationSuspensionBehaviorCoalesce, 2)
         self.assertEqual(CFNotificationSuspensionBehaviorHold, 3)
         self.assertEqual(CFNotificationSuspensionBehaviorDeliverImmediately, 4)
+
         self.assertEqual(kCFNotificationDeliverImmediately, 1)
         self.assertEqual(kCFNotificationPostToAllSessions, 2)
 
-
 if __name__ == "__main__":
     main()
