@@ -2,29 +2,41 @@ from PyObjCTools.TestSupport import *
 import os
 from CoreFoundation import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 
 class TestPreferences (TestCase):
     def testGetting(self):
-        v = CFPreferencesCopyAppValue("WindowCloseAction", "com.apple.Terminal")
+        v = CFPreferencesCopyAppValue("Default Window Settings", "com.apple.Terminal")
         self.assertIsInstance(v, unicode)
         self.assertResultIsBOOL(CFPreferencesGetAppBooleanValue)
         self.assertArgHasType(CFPreferencesGetAppBooleanValue, 2, b'o^Z')
-        v, valid = CFPreferencesGetAppBooleanValue("AutoFocus", "com.apple.Terminal", None)
+        v, valid = CFPreferencesGetAppBooleanValue("SecureKeyboardEntry", "com.apple.Terminal", None)
         self.assertTrue(valid)
         self.assertIsInstance(v, bool)
         self.assertArgHasType(CFPreferencesGetAppIntegerValue, 2, b'o^Z')
-        v, valid = CFPreferencesGetAppIntegerValue("WindowCloseAction", "com.apple.Terminal", None)
+        v, valid = CFPreferencesGetAppIntegerValue("ABMetaDataChangeCount", "com.apple.AddressBook", None)
         self.assertTrue(valid)
         self.assertIsInstance(v, (int, long))
-        v = CFPreferencesCopyValue("WindowCloseAction", "com.apple.Terminal", kCFPreferencesCurrentUser, kCFPreferencesAnyHost)
+        v = CFPreferencesCopyValue("Default Window Settings", "com.apple.Terminal", kCFPreferencesCurrentUser, kCFPreferencesAnyHost)
         self.assertIsInstance(v, unicode)
         v = CFPreferencesCopyMultiple(None, "com.apple.Terminal", kCFPreferencesCurrentUser, kCFPreferencesAnyHost)
         self.assertIsInstance(v, CFDictionaryRef)
-        v = CFPreferencesCopyMultiple([u"AutoFocus", u"WindowCloseAction"], "com.apple.Terminal", kCFPreferencesCurrentUser, kCFPreferencesAnyHost)
+        v = CFPreferencesCopyMultiple([b"AutoFocus".decode('ascii'), b"WindowCloseAction".decode('ascii')], "com.apple.Terminal", kCFPreferencesCurrentUser, kCFPreferencesAnyHost)
         self.assertIsInstance(v, CFDictionaryRef)
         self.assertResultIsBOOL(CFPreferencesAppValueIsForced)
         v = CFPreferencesAppValueIsForced("AutoFocus", "com.apple.Terminal")
         self.assertIs(v is True or v, False)
+
     def testSetting(self):
         prefsFn = os.path.expanduser('~/Library/Preferences/PyObjCTest.plist')
         if os.path.exists(prefsFn):
@@ -40,8 +52,8 @@ class TestPreferences (TestCase):
 
         ok = CFPreferencesAppSynchronize("PyObjCTest")
         self.assertTrue(ok)
-        self.assertTrue(os.path.exists(prefsFn))
-        os.unlink(prefsFn)
+        listing = os.listdir(os.path.dirname(prefsFn))
+        self.assertTrue([fn for fn in listing if fn.startswith(os.path.basename(prefsFn))])
 
         CFPreferencesSetValue("PyObjCTestValue2", "value2", "PyObjCTest", kCFPreferencesCurrentUser, kCFPreferencesAnyHost)
         v = CFPreferencesCopyValue("PyObjCTestValue2", "PyObjCTest", kCFPreferencesCurrentUser, kCFPreferencesAnyHost)
@@ -62,18 +74,20 @@ class TestPreferences (TestCase):
         if os.path.exists(prefsFn):
             os.unlink(prefsFn)
         ok = CFPreferencesSynchronize("PyObjCTest", kCFPreferencesCurrentUser, kCFPreferencesAnyHost)
+
         self.assertTrue(ok)
-        self.assertTrue(os.path.exists(prefsFn))
-        os.unlink(prefsFn)
+        listing = os.listdir(os.path.dirname(prefsFn))
+        self.assertTrue([fn for fn in listing if fn.startswith(os.path.basename(prefsFn))])
 
         self.assertResultIsCFRetained(CFPreferencesCopyApplicationList)
         apps = CFPreferencesCopyApplicationList(kCFPreferencesCurrentUser, kCFPreferencesAnyHost)
         self.assertIsInstance(apps, CFArrayRef)
-        self.assertIsIn(u"com.apple.AddressBook", apps)
+        self.assertIsIn(b"com.apple.AddressBook".decode('ascii'), apps)
         self.assertResultIsCFRetained(CFPreferencesCopyKeyList)
-        keys = CFPreferencesCopyKeyList(u"com.apple.AddressBook", kCFPreferencesCurrentUser, kCFPreferencesAnyHost)
+        keys = CFPreferencesCopyKeyList(b"com.apple.AddressBook".decode('ascii'), kCFPreferencesCurrentUser, kCFPreferencesAnyHost)
         self.assertIsInstance(keys, CFArrayRef)
-        self.assertIsIn(u"ABNameSorting", keys)
+        self.assertTrue(b"ABVersion".decode('ascii') in keys or b"ABNameDisplay".decode('ascii') in keys)
+
     def testConstants(self):
         self.assertIsInstance(kCFPreferencesAnyApplication, unicode)
         self.assertIsInstance(kCFPreferencesCurrentApplication, unicode)
@@ -81,5 +95,6 @@ class TestPreferences (TestCase):
         self.assertIsInstance(kCFPreferencesCurrentHost, unicode)
         self.assertIsInstance(kCFPreferencesAnyUser, unicode)
         self.assertIsInstance(kCFPreferencesCurrentUser, unicode)
+
 if __name__ == "__main__":
     main()
