@@ -1,6 +1,19 @@
 from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 import errno, time, os, socket, sys
+import contextlib
+
+from .test_cfsocket import onTheNetwork
+
+try:
+    long
+except NameError:
+    long = int
+
+try:
+    unicode
+except NameError:
+    unicode = str
 
 
 class TestStream (TestCase):
@@ -97,7 +110,7 @@ class TestStream (TestCase):
 
         self.assertResultIsCFRetained(CFReadStreamCreateWithFile)
         stream = CFReadStreamCreateWithFile(None, 
-                    CFURLCreateWithString(None, u"file:///etc/shells", None))
+                    CFURLCreateWithString(None, b"file:///etc/shells".decode('ascii'), None))
         self.assertIsInstance(stream, CFReadStreamRef)
         r = CFReadStreamOpen(stream)
         self.assertIs(r, True)
@@ -130,6 +143,7 @@ class TestStream (TestCase):
         self.assertIsInstance(err, CFStreamError)
         self.assertEqual(err.domain , 0)
         self.assertEqual(err.error , 0)
+
     def testWriteStream(self):
         import array
         a = array.array('b', b" "*20)
@@ -204,7 +218,7 @@ class TestStream (TestCase):
 
 
         stream = CFWriteStreamCreateWithFile(None, 
-                CFURLCreateWithString(None, u"file:///tmp/pyobjc.test.txt", None))
+                CFURLCreateWithString(None, b"file:///tmp/pyobjc.test.txt".decode('ascii'), None))
         self.assertIsInstance(stream, CFWriteStreamRef)
         r = CFWriteStreamOpen(stream)
         self.assertIs(r, True)
@@ -229,7 +243,8 @@ class TestStream (TestCase):
         self.assertResultIsBOOL(CFWriteStreamSetProperty)
         CFWriteStreamSetProperty(stream, kCFStreamPropertyFileCurrentOffset, 0)
 
-        data = open('/tmp/pyobjc.test.txt', 'rb').read()
+        with open('/tmp/pyobjc.test.txt', 'rb') as fp:
+            data = fp.read()
         self.assertEqual(data, b'0123456789ABCDE')
         os.unlink('/tmp/pyobjc.test.txt')
 
@@ -251,24 +266,25 @@ class TestStream (TestCase):
 
         del readStream, writeStream
 
+    @onlyIf(onTheNetwork)
     def testSockets(self):
-        sd = socket.socket(socket.AF_INET, socket.SOCK_STREAM) 
-        sd.connect(('www.apple.com', 80))
+        with contextlib.closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as sd:
+            sd.connect(('www.apple.com', 80))
 
-        self.assertArgIsOut(CFStreamCreatePairWithSocket, 2)
-        self.assertArgIsOut(CFStreamCreatePairWithSocket, 3)
-        readStream, writeStream = CFStreamCreatePairWithSocket(None,
-                sd.fileno(), None, None)
+            self.assertArgIsOut(CFStreamCreatePairWithSocket, 2)
+            self.assertArgIsOut(CFStreamCreatePairWithSocket, 3)
+            readStream, writeStream = CFStreamCreatePairWithSocket(None,
+                    sd.fileno(), None, None)
 
-        status = CFReadStreamGetStatus(readStream)
-        self.assertIsInstance(status, (int, long))
-        self.assertEqual(status, kCFStreamStatusNotOpen)
+            status = CFReadStreamGetStatus(readStream)
+            self.assertIsInstance(status, (int, long))
+            self.assertEqual(status, kCFStreamStatusNotOpen)
 
-        status = CFWriteStreamGetStatus(writeStream)
-        self.assertIsInstance(status, (int, long))
-        self.assertEqual(status, kCFStreamStatusNotOpen)
+            status = CFWriteStreamGetStatus(writeStream)
+            self.assertIsInstance(status, (int, long))
+            self.assertEqual(status, kCFStreamStatusNotOpen)
 
-        del readStream, writeStream, sd
+            del readStream, writeStream, sd
 
         self.assertArgIsOut(CFStreamCreatePairWithSocketToHost, 3)
         self.assertArgIsOut(CFStreamCreatePairWithSocketToHost, 4)
