@@ -4,6 +4,17 @@ from CoreFoundation import *
 from Foundation import NSDictionary, NSString, NSMutableDictionary
 import sys
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 
 class TestTimeZone (TestCase):
     def testTypes(self):
@@ -12,15 +23,19 @@ class TestTimeZone (TestCase):
     def testTypeID(self):
         id = CFTimeZoneGetTypeID()
         self.assertIsInstance(id, (int, long))
+
     def testSystemZone(self):
         zone = CFTimeZoneCopySystem()
         self.assertIsInstance(zone, CFTimeZoneRef)
+
     def testResetSystem(self):
         v = CFTimeZoneResetSystem()
         self.assertIs(v, None )
+
     def testCopyDefault(self):
         zone = CFTimeZoneCopyDefault()
         self.assertIsInstance(zone, CFTimeZoneRef)
+
     def testNames(self):
         self.assertResultIsCFRetained(CFTimeZoneCopyKnownNames)
         array = CFTimeZoneCopyKnownNames()
@@ -28,12 +43,14 @@ class TestTimeZone (TestCase):
         self.assertNotEqual(len(array) , 0 )
         for nm in array:
             self.assertIsInstance(nm, unicode)
+
     def testAbbreviationDict(self):
         map = CFTimeZoneCopyAbbreviationDictionary()
         self.assertIsInstance(map, CFDictionaryRef)
         for key, value in map.items():
             self.assertIsInstance(key, unicode)
             self.assertIsInstance(value, unicode)
+
     @min_os_level('10.6')
     def testAbbrievationDictSetting(self):
         # Setting the dictionary is technically also possible
@@ -41,22 +58,23 @@ class TestTimeZone (TestCase):
         # rewritten als plan Objective-C.
         map = CFTimeZoneCopyAbbreviationDictionary()
         newmap = map.mutableCopy()
-        newmap[u'AAA'] = u'Europe/Amsterdam'
+        newmap[b'AAA'.decode('ascii')] = b'Europe/Amsterdam'.decode('ascii')
 
         v = CFTimeZoneSetAbbreviationDictionary(newmap)
         self.assertIs(v, None)
         try:
             map2 = CFTimeZoneCopyAbbreviationDictionary()
             self.assertIsInstance(map2, CFDictionaryRef)
-            self.assertEqual(map2[u'AAA'] , u'Europe/Amsterdam' )
+            self.assertEqual(map2[b'AAA'.decode('ascii')] , b'Europe/Amsterdam'.decode('ascii') )
         finally:
             CFTimeZoneSetAbbreviationDictionary(map)
 
     def testZoneObject(self):
-        data = open('/usr/share/zoneinfo/posixrules', 'rb').read()
+        with open('/usr/share/zoneinfo/posixrules', 'rb') as fp:
+            data = fp.read()
         if sys.version_info[0] == 2:
             data = buffer(data)
-        zone = CFTimeZoneCreate(None, u"Europe/Amsterdam", data)
+        zone = CFTimeZoneCreate(None, b"Europe/Amsterdam".decode('ascii'), data)
         self.assertIsInstance(zone, CFTimeZoneRef)
         self.assertResultIsCFRetained(CFTimeZoneCreateWithTimeIntervalFromGMT)
         zone = CFTimeZoneCreateWithTimeIntervalFromGMT(None, 3600)
@@ -67,7 +85,7 @@ class TestTimeZone (TestCase):
         zone = CFTimeZoneCreateWithName(None, "Europe/Amsterdam", True)
         self.assertIsInstance(zone, CFTimeZoneRef)
         name = CFTimeZoneGetName(zone)
-        self.assertEqual(name, u"Europe/Amsterdam")
+        self.assertEqual(name, b"Europe/Amsterdam".decode('ascii'))
 
         data = CFTimeZoneGetData(zone)
         self.assertIsInstance(data, CFDataRef)
@@ -104,18 +122,16 @@ class TestTimeZone (TestCase):
         nm = CFTimeZoneCopyLocalizedName(zone, 
                 kCFTimeZoneNameStyleShortStandard, CFLocaleCopyCurrent())
         self.assertIsInstance(nm, unicode)
+
     def testConstants(self):
         self.assertEqual(kCFTimeZoneNameStyleStandard , 0 )
         self.assertEqual(kCFTimeZoneNameStyleShortStandard , 1 )
         self.assertEqual(kCFTimeZoneNameStyleDaylightSaving , 2 )
         self.assertEqual(kCFTimeZoneNameStyleShortDaylightSaving , 3 )
         self.assertIsInstance(kCFTimeZoneSystemTimeZoneDidChangeNotification, unicode)
-    @min_os_level('10.6')
-    def testConstants10_6(self):
         self.assertEqual(kCFTimeZoneNameStyleGeneric, 4)
         self.assertEqual(kCFTimeZoneNameStyleShortGeneric, 5)
 
 
-
 if __name__ == "__main__":
     main()
