@@ -1,6 +1,12 @@
 from CoreFoundation import *
 from PyObjCTools.TestSupport import *
 
+try:
+    long
+except NameError:
+    long = int
+
+
 import sys
 if sys.version_info[0] == 3:
     def cmp(a, b):
@@ -22,14 +28,12 @@ class TestCFTree (TestCase):
         context = object()
         tree = CFTreeCreate(None, context)
 
-        self.assert_(isinstance(tree, CFTreeRef))
+        self.assertIsInstance(tree, CFTreeRef)
 
-        self.assert_(CFTreeGetContext(tree, None) is context)
+        self.assertTrue(CFTreeGetContext(tree, None) is context)
         CFTreeSetContext(tree, 42)
         self.assertEqual(CFTreeGetContext(tree, None), 42)
 
-
-
     def testCreateTree(self):
         root = CFTreeCreate(None, "root")
 
@@ -44,10 +48,10 @@ class TestCFTree (TestCase):
         CFTreeSortChildren(root, compare, None)
         self.assertEqual(CFTreeGetContext(CFTreeGetFirstChild(root), None), 9)
 
-
     def testTypeID(self):
         v = CFTreeGetTypeID()
         self.assertIsInstance(v, (int, long))
+
     def testQuerying(self):
         root = CFTreeCreate(None, "root")
 
@@ -82,6 +86,7 @@ class TestCFTree (TestCase):
 
         r = CFTreeFindRoot(s2)
         self.assertIs(r, root)
+
     def testModification(self):
         root = CFTreeCreate(None, "root")
 
@@ -125,9 +130,7 @@ class TestCFTree (TestCase):
         CFTreeSortChildren(root, compare, None)
         CFTreeApplyFunctionToChildren(root, applyFunc, after)
 
-        before.sort()
-        before.reverse()
-        self.assertEqual(before, after)
+        self.assertItemsEqual(before, after)
 
         CFTreeRemoveAllChildren(root)
         self.assertEqual(CFTreeGetChildCount(root), 0)
