@@ -4,10 +4,22 @@ from CoreFoundation import *
 import os
 from Foundation import NSURL
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 
 class TestURL (TestCase):
     def testTypes(self):
         self.assertIs(CFURLRef, NSURL)
+
     def testTypeID(self):
         val = CFURLGetTypeID()
         self.assertIsInstance(val, (int, long))
@@ -48,7 +60,7 @@ class TestURL (TestCase):
         self.assertEqual(val, url.replace(b' ', b'%20'))
 
     def testCreateWithString(self):
-        url = u"http://www.omroep.nl/"
+        url = b"http://www.omroep.nl/".decode('ascii')
 
         ref = CFURLCreateWithString(None, url, None)
         self.assertIsInstance(ref, CFURLRef)
@@ -60,7 +72,7 @@ class TestURL (TestCase):
         self.assertIsInstance(ref2, CFURLRef)
 
     def testCreateAbsolute(self):
-        url = u"http://www.omroep.nl/sport/"
+        url = b"http://www.omroep.nl/sport/".decode('ascii')
         baseref = CFURLCreateWithString(None, url, None)
 
         self.assertArgHasType(CFURLCreateAbsoluteURLWithBytes, 1, b'n^v')
@@ -69,41 +81,42 @@ class TestURL (TestCase):
         self.assertIsInstance(ref, CFURLRef)
 
         strval =  CFURLGetString(ref)
-        self.assertEqual(strval, u"http://www.omroep.nl/sport/socker")
+        self.assertEqual(strval, b"http://www.omroep.nl/sport/socker".decode('ascii'))
 
         relpath = b"../../../dummy"
         ref = CFURLCreateAbsoluteURLWithBytes(None, relpath, len(relpath), kCFStringEncodingUTF8, baseref, True)
         self.assertIsInstance(ref, CFURLRef)
         strval =  CFURLGetString(ref)
-        self.assertEqual(strval, u"http://www.omroep.nl/dummy")
+        self.assertEqual(strval, b"http://www.omroep.nl/dummy".decode('ascii'))
 
         relpath = b"../../../dummy"
         ref = CFURLCreateAbsoluteURLWithBytes(None, relpath, len(relpath), kCFStringEncodingUTF8, baseref, False)
         self.assertIsInstance(ref, CFURLRef)
         strval =  CFURLGetString(ref)
-        self.assertEqual(strval, u"http://www.omroep.nl/../../dummy")
+        self.assertEqual(strval, b"http://www.omroep.nl/../../dummy".decode('ascii'))
 
 
     def testCopyAbs(self):
         # CFURLCopyAbsoluteURL
-        base = CFURLCreateWithString(None, u"http://www.omroep.nl/", None)
+        base = CFURLCreateWithString(None, b"http://www.omroep.nl/".decode('ascii'), None)
         self.assertIsInstance(base, CFURLRef)
 
-        ref = CFURLCreateWithString(None, u"/sport", base)
+        ref = CFURLCreateWithString(None, b"/sport".decode('ascii'), base)
         self.assertIsInstance(ref, CFURLRef)
 
-        self.assertEqual(CFURLGetString(ref) , u"/sport" )
+        self.assertEqual(CFURLGetString(ref) , b"/sport".decode('ascii') )
         abs = CFURLCopyAbsoluteURL(ref)
         self.assertIsInstance(abs, CFURLRef)
-        self.assertEqual(CFURLGetString(abs) , u"http://www.omroep.nl/sport" )
+        self.assertEqual(CFURLGetString(abs) , b"http://www.omroep.nl/sport".decode('ascii') )
+
     def testPaths(self):
         url = CFURLCreateWithFileSystemPath(None,
-                u"/tmp/", kCFURLPOSIXPathStyle, True)
+                b"/tmp/".decode('ascii'), kCFURLPOSIXPathStyle, True)
         self.assertIsInstance(url, CFURLRef)
         self.assertTrue(CFURLHasDirectoryPath(url))
 
         url = CFURLCreateWithFileSystemPath(None,
-                u"/etc/hosts", kCFURLPOSIXPathStyle, False)
+                b"/etc/hosts".decode('ascii'), kCFURLPOSIXPathStyle, False)
         self.assertIsInstance(url, CFURLRef)
         self.assertFalse(CFURLHasDirectoryPath(url))
 
@@ -116,19 +129,19 @@ class TestURL (TestCase):
         self.assertIsInstance(url, CFURLRef)
         self.assertRaises((ValueError, TypeError),
             CFURLCreateFromFileSystemRepresentation, None,
-                u"/tmp/", 4, True)
+                b"/tmp/".decode('ascii'), 4, True)
 
         base = CFURLCreateWithFileSystemPath(None,
-                u"/tmp", kCFURLPOSIXPathStyle, True)
+                b"/tmp".decode('ascii'), kCFURLPOSIXPathStyle, True)
         self.assertIsInstance(base, CFURLRef)
 
         self.assertArgIsBOOL(CFURLCreateWithFileSystemPathRelativeToBase, 3)
         url = CFURLCreateWithFileSystemPathRelativeToBase(None,
-                u"filename", kCFURLPOSIXPathStyle, True, base)
+                b"filename".decode('ascii'), kCFURLPOSIXPathStyle, True, base)
         self.assertIsInstance(url, CFURLRef)
 
         strval =  CFURLGetString(url)
-        self.assertEqual(strval, u"filename/")
+        self.assertEqual(strval, b"filename/".decode('ascii'))
 
 
         self.assertArgIsBOOL(CFURLCreateFromFileSystemRepresentationRelativeToBase, 3)
@@ -136,42 +149,42 @@ class TestURL (TestCase):
                 b"filename2", 9, False, base)
         self.assertIsInstance(url, CFURLRef)
         strval =  CFURLGetString(url)
-        self.assertEqual(strval, u"filename2")
+        self.assertEqual(strval, b"filename2".decode('ascii'))
 
         ok, strval = CFURLGetFileSystemRepresentation(url, True, None, 100)
         self.assertTrue(ok)
 
         # Unfortunately metadata doesn't allow describing what we actually need
         if b'\0' in strval:
-            strval = strval[:strval.index('\0')]
-        self.assertEqual(strval, u"/tmp/filename2")
+            strval = strval[:strval.index(b'\0')]
+        self.assertEqual(strval, b"/tmp/filename2")
 
     def testParts(self):
-        base = CFURLCreateWithString(None, u"http://www.omroep.nl/", None)
+        base = CFURLCreateWithString(None, b"http://www.omroep.nl/".decode('ascii'), None)
         self.assertIsInstance(base, CFURLRef)
 
-        ref = CFURLCreateWithString(None, u"/sport", base)
+        ref = CFURLCreateWithString(None, b"/sport".decode('ascii'), base)
         self.assertIsInstance(ref, CFURLRef)
 
         self.assertEqual(CFURLGetBaseURL(base), None)
         self.assertEqual(CFURLGetBaseURL(ref), base)
-        self.assert_(CFURLCanBeDecomposed(ref) is True)
+        self.assertTrue(CFURLCanBeDecomposed(ref) is True)
 
-        self.assertEqual(CFURLCopyScheme(ref), u"http")
-        self.assertEqual(CFURLCopyNetLocation(ref), u"www.omroep.nl")
-        self.assertEqual(CFURLCopyPath(ref), u"/sport")
+        self.assertEqual(CFURLCopyScheme(ref), b"http".decode('ascii'))
+        self.assertEqual(CFURLCopyNetLocation(ref), b"www.omroep.nl".decode('ascii'))
+        self.assertEqual(CFURLCopyPath(ref), b"/sport".decode('ascii'))
 
         path, isDir = CFURLCopyStrictPath(ref, None)
-        self.assertEqual(path, u"sport")
+        self.assertEqual(path, b"sport".decode('ascii'))
         self.assertEqual(isDir, True)
 
         path = CFURLCopyFileSystemPath(ref, kCFURLPOSIXPathStyle)
-        self.assertEqual(path, u"/sport")
+        self.assertEqual(path, b"/sport".decode('ascii'))
 
         path = CFURLCopyFileSystemPath(ref, kCFURLPOSIXPathStyle)
-        self.assertEqual(path, u"/sport")
+        self.assertEqual(path, b"/sport".decode('ascii'))
         path = CFURLCopyFileSystemPath(ref, kCFURLWindowsPathStyle)
-        self.assertEqual(path, u"\\sport")
+        self.assertEqual(path, b"\\sport".decode('ascii'))
 
         self.assertFalse(CFURLHasDirectoryPath(ref))
 
@@ -184,12 +197,12 @@ class TestURL (TestCase):
         v =  CFURLGetPortNumber(ref)
         self.assertEqual(v, -1)
 
-        ref = CFURLCreateWithString(None, u"https://ronald:test@www.nu.nl:42/sport/results.cgi?qs=1#anchor", None)
+        ref = CFURLCreateWithString(None, b"https://ronald:test@www.nu.nl:42/sport/results.cgi?qs=1#anchor".decode('ascii'), None)
         v =  CFURLGetPortNumber(ref)
         self.assertEqual(v, 42)
 
         v = CFURLCopyResourceSpecifier(ref)
-        self.assertEqual(v, u"?qs=1#anchor")
+        self.assertEqual(v, b"?qs=1#anchor".decode('ascii'))
 
         v = CFURLCopyUserName(ref)
         self.assertEqual(v, "ronald")
@@ -224,7 +237,7 @@ class TestURL (TestCase):
         
 
     def testUpdating(self):
-        base = CFURLCreateWithString(None, u"http://www.omroep.nl/sport", None)
+        base = CFURLCreateWithString(None, b"http://www.omroep.nl/sport".decode('ascii'), None)
         self.assertIsInstance(base, CFURLRef)
 
         url = CFURLCreateCopyAppendingPathComponent(None, base, "soccer", True)
@@ -249,7 +262,7 @@ class TestURL (TestCase):
         self.assertEqual(strval, "http://www.omroep.nl/sport")
 
     def testStringEncoding(self):
-        base = u"http://www.omroep.nl/sport%20en%20%73%70el"
+        base = b"http://www.omroep.nl/sport%20en%20%73%70el".decode('ascii')
 
         strval = CFURLCreateStringByReplacingPercentEscapes(None, base, objc.NULL)
         self.assertEqual(strval, "http://www.omroep.nl/sport%20en%20%73%70el")
@@ -264,13 +277,13 @@ class TestURL (TestCase):
         self.assertEqual(strval, "http://www.omroep.nl/sport en spel")
 
         
-        base = u"http://www.omroep.nl/sport en spel"
+        base = b"http://www.omroep.nl/sport en spel".decode('ascii')
         strval = CFURLCreateStringByAddingPercentEscapes(None, base, "", "",
                 kCFStringEncodingISOLatin1)
-        self.assertEqual(strval, u"http://www.omroep.nl/sport%20en%20spel")
+        self.assertEqual(strval, b"http://www.omroep.nl/sport%20en%20spel".decode('ascii'))
         strval = CFURLCreateStringByAddingPercentEscapes(None, base, " ", "s",
                 kCFStringEncodingISOLatin1)
-        self.assertEqual(strval, u"http://www.omroep.nl/%73port en %73pel")
+        self.assertEqual(strval, b"http://www.omroep.nl/%73port en %73pel".decode('ascii'))
 
     def testFSRef(self):
         ref = CFURLCreateWithFileSystemPath(None, os.getcwd(), kCFURLPOSIXPathStyle, True)
@@ -308,7 +321,8 @@ class TestURL (TestCase):
         fp.close()
         try:
             baseURL = CFURLCreateWithFileSystemPath(None,
-                u"/tmp/pyobjc.test", kCFURLPOSIXPathStyle, False)
+                os.path.realpath(b"/tmp/pyobjc.test".decode('ascii')), 
+                kCFURLPOSIXPathStyle, False)
             self.assertIsInstance(baseURL, CFURLRef)
 
             self.assertResultIsCFRetained(CFURLCreateFileReferenceURL)
@@ -349,10 +363,10 @@ class TestURL (TestCase):
             self.assertIsInstance(v, bool)
             self.assertEqual(err, None)
 
-            CFURLSetTemporaryResourcePropertyForKey(url, "pyobjc.test", u"hello")
+            CFURLSetTemporaryResourcePropertyForKey(url, "pyobjc.test", b"hello".decode('ascii'))
             ok, v, err = CFURLCopyResourcePropertyForKey(url, "pyobjc.test", None, None)
             self.assertTrue(ok)
-            self.assertEqual(v, u"hello")
+            self.assertEqual(v, b"hello".decode('ascii'))
 
             ok, cur, err = CFURLCopyResourcePropertyForKey(url, kCFURLIsHiddenKey, None, None)
             self.assertTrue(ok)
@@ -394,7 +408,7 @@ class TestURL (TestCase):
             self.assertIsInstance(v, unicode)
 
             refURL = CFURLCreateWithFileSystemPath(None,
-                u"/tmp/pyobjc.test.2", kCFURLPOSIXPathStyle, False)
+                b"/tmp/pyobjc.test.2".decode('ascii'), kCFURLPOSIXPathStyle, False)
             ok, err = CFURLWriteBookmarkDataToFile(data, refURL, 0, None)
             self.assertTrue(ok)
             self.assertIs(err, None)
@@ -413,6 +427,21 @@ class TestURL (TestCase):
             if os.path.exists('/tmp/pyobjc.test.2'):
                 os.unlink('/tmp/pyobjc.test.2')
 
+    @min_os_level('10.8')
+    def testFunctions10_8(self):
+        self.assertResultIsBOOL(CFURLStartAccessingSecurityScopedResource)
+
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertIsInstance(kCFURLIsExcludedFromBackupKey, unicode)
+
+        self.assertIsInstance(kCFURLPathKey, unicode)
+
+        self.assertEqual(kCFBookmarkResolutionWithoutUIMask, 1 << 8)
+        self.assertEqual(kCFBookmarkResolutionWithoutMountingMask, 1 << 9)
+        self.assertEqual(kCFURLBookmarkResolutionWithSecurityScope, 1 << 10)
+
+
     @min_os_level('10.6')
     def testConstants10_6(self):
         self.assertIsInstance(kCFURLNameKey, unicode)
@@ -463,7 +492,54 @@ class TestURL (TestCase):
         self.assertEqual(kCFBookmarkResolutionWithoutUIMask, 1<<8)
         self.assertEqual(kCFBookmarkResolutionWithoutMountingMask, 1<<9)
 
-
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertIsInstance(kCFURLKeysOfUnsetValuesKey, unicode)
+        self.assertIsInstance(kCFURLFileResourceIdentifierKey, unicode)
+        self.assertIsInstance(kCFURLVolumeIdentifierKey, unicode)
+        self.assertIsInstance(kCFURLPreferredIOBlockSizeKey, unicode)
+        self.assertIsInstance(kCFURLIsReadableKey, unicode)
+        self.assertIsInstance(kCFURLIsWritableKey, unicode)
+        self.assertIsInstance(kCFURLIsExecutableKey, unicode)
+        self.assertIsInstance(kCFURLFileSecurityKey, unicode)
+        self.assertIsInstance(kCFURLFileResourceTypeKey, unicode)
+        self.assertIsInstance(kCFURLFileResourceTypeNamedPipe, unicode)
+        self.assertIsInstance(kCFURLFileResourceTypeCharacterSpecial, unicode)
+        self.assertIsInstance(kCFURLFileResourceTypeDirectory, unicode)
+        self.assertIsInstance(kCFURLFileResourceTypeBlockSpecial, unicode)
+        self.assertIsInstance(kCFURLFileResourceTypeRegular, unicode)
+        self.assertIsInstance(kCFURLFileResourceTypeSymbolicLink, unicode)
+        self.assertIsInstance(kCFURLFileResourceTypeSocket, unicode)
+        self.assertIsInstance(kCFURLFileResourceTypeUnknown, unicode)
+        self.assertIsInstance(kCFURLTotalFileSizeKey, unicode)
+        self.assertIsInstance(kCFURLTotalFileAllocatedSizeKey, unicode)
+        self.assertIsInstance(kCFURLIsMountTriggerKey, unicode)
+        self.assertIsInstance(kCFURLVolumeSupportsRootDirectoryDatesKey, unicode)
+        self.assertIsInstance(kCFURLVolumeSupportsVolumeSizesKey, unicode)
+        self.assertIsInstance(kCFURLVolumeSupportsRenamingKey, unicode)
+        self.assertIsInstance(kCFURLVolumeSupportsAdvisoryFileLockingKey, unicode)
+        self.assertIsInstance(kCFURLVolumeSupportsExtendedSecurityKey, unicode)
+        self.assertIsInstance(kCFURLVolumeIsBrowsableKey, unicode)
+        self.assertIsInstance(kCFURLVolumeMaximumFileSizeKey, unicode)
+        self.assertIsInstance(kCFURLVolumeIsEjectableKey, unicode)
+        self.assertIsInstance(kCFURLVolumeIsRemovableKey, unicode)
+        self.assertIsInstance(kCFURLVolumeIsInternalKey, unicode)
+        self.assertIsInstance(kCFURLVolumeIsAutomountedKey, unicode)
+        self.assertIsInstance(kCFURLVolumeIsLocalKey, unicode)
+        self.assertIsInstance(kCFURLVolumeIsReadOnlyKey, unicode)
+        self.assertIsInstance(kCFURLVolumeCreationDateKey, unicode)
+        self.assertIsInstance(kCFURLVolumeURLForRemountingKey, unicode)
+        self.assertIsInstance(kCFURLVolumeUUIDStringKey, unicode)
+        self.assertIsInstance(kCFURLVolumeNameKey, unicode)
+        self.assertIsInstance(kCFURLVolumeLocalizedNameKey, unicode)
+        self.assertIsInstance(kCFURLIsUbiquitousItemKey, unicode)
+        self.assertIsInstance(kCFURLUbiquitousItemHasUnresolvedConflictsKey, unicode)
+        self.assertIsInstance(kCFURLUbiquitousItemIsDownloadedKey, unicode)
+        self.assertIsInstance(kCFURLUbiquitousItemIsDownloadingKey, unicode)
+        self.assertIsInstance(kCFURLUbiquitousItemIsUploadedKey, unicode)
+        self.assertIsInstance(kCFURLUbiquitousItemIsUploadingKey, unicode)
+        self.assertIsInstance(kCFURLUbiquitousItemPercentDownloadedKey, unicode)
+        self.assertIsInstance(kCFURLUbiquitousItemPercentUploadedKey, unicode)
 
 if __name__ == "__main__":
     main()
