@@ -1,6 +1,17 @@
 from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestUserNotification (TestCase):
     def testTypes(self):
         self.assertIsCFType(CFUserNotificationRef)
@@ -8,11 +19,15 @@ class TestUserNotification (TestCase):
     def testTypeID(self):
         id = CFUserNotificationGetTypeID()
         self.assertIsInstance(id, (int, long))
+
     def testCreation(self):
+        runloop_mode = kCFRunLoopDefaultMode
+        runloop_mode = b"pyobjctest.cfusernotificaton".decode('ascii')
+
         rl = CFRunLoopGetCurrent()
 
         infoDict = {
-                kCFUserNotificationAlertHeaderKey: u"Alert Header",
+                kCFUserNotificationAlertHeaderKey: b"Alert Header".decode('ascii'),
                 kCFUserNotificationProgressIndicatorValueKey: True,
                 kCFUserNotificationDefaultButtonTitleKey: "Cancel"
         }
@@ -30,11 +45,12 @@ class TestUserNotification (TestCase):
         self.assertArgIsFunction(CFUserNotificationCreateRunLoopSource, 2, b'v^{__CFUserNotification=}' + objc._C_NSInteger, True)
         rls = CFUserNotificationCreateRunLoopSource(None, ref, callout, 1)
         self.assertIsInstance(rls, CFRunLoopSourceRef)
-        CFRunLoopAddSource(rl, rls, kCFRunLoopDefaultMode)
-        CFRunLoopRunInMode(kCFRunLoopDefaultMode, 2.0, True)
+        CFRunLoopAddSource(rl, rls, runloop_mode)
+        CFRunLoopRunInMode(runloop_mode, 2.0, True)
 
         CFUserNotificationCancel(ref)
-        CFRunLoopRunInMode(kCFRunLoopDefaultMode, 1.0, True)
+        CFRunLoopRunInMode(runloop_mode, 5.0, True)
+        CFRunLoopRemoveSource(rl, rls, runloop_mode)
 
         self.assertEqual(len(values), 1)
         self.assertIs(values[0][0], ref)
@@ -55,6 +71,7 @@ class TestUserNotification (TestCase):
         v = CFUserNotificationGetResponseValue(ref, kCFUserNotificationTextFieldValuesKey, 0)
         if v is not None:
             self.assertIsInstance(v, unicode)
+
     def testAlert(self):
         err, flags = CFUserNotificationDisplayAlert(0.1, 0, None, None, None, "Header", "Message", "Cancel", None, None, None)
         self.assertEqual(err , 0)
@@ -62,9 +79,11 @@ class TestUserNotification (TestCase):
         err, flags = CFUserNotificationDisplayAlert(0.1, 0, None, None, None, "Header", "Message", "Cancel", "OK", "Rest", None)
         self.assertEqual(err , 0)
         self.assertIsInstance(flags, (int, long))
+
     def testNotice(self):
         err = CFUserNotificationDisplayNotice(0.1, 0, None, None, None, "Header", "Message", "Cancel")
         self.assertEqual(err , 0)
+
     def testInlines(self):
         flag = CFUserNotificationCheckBoxChecked(2)
         self.assertEqual(flag , 1 << 10 )
@@ -72,6 +91,7 @@ class TestUserNotification (TestCase):
         self.assertEqual(flag , 1 << 18 )
         flag = CFUserNotificationPopUpSelection(2)
         self.assertEqual(flag , 2 << 24 )
+
     def testConstants(self):
         self.assertEqual(kCFUserNotificationStopAlertLevel       , 0)
         self.assertEqual(kCFUserNotificationNoteAlertLevel       , 1)
@@ -97,5 +117,7 @@ class TestUserNotification (TestCase):
         self.assertIsInstance(kCFUserNotificationCheckBoxTitlesKey, unicode)
         self.assertIsInstance(kCFUserNotificationTextFieldValuesKey, unicode)
         self.assertIsInstance(kCFUserNotificationPopUpSelectionKey, unicode)
+
+
 if __name__ == "__main__":
     main()
