@@ -5,6 +5,17 @@ import struct
 import Foundation
 import os
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 class GlobalFunctionTest (TestCase):
     if sys.platform == 'darwin':
         def testNSFileTypeForHFSTypeCode(self):
@@ -39,6 +50,7 @@ class GlobalFunctionTest (TestCase):
                 Foundation.NSMakeRect(1, 2, 3, 4),
                 ((1.0, 2.0), (3.0, 4.0))
         )
+        self.assertIsInstance(Foundation.NSMakeRect(1, 2, 3, 4), Foundation.NSRect)
 
         self.assertRaises(ValueError, Foundation.NSMakeRect, 1.0, 2.0, 3.0, '4')
 
@@ -80,7 +92,8 @@ class NSLogTest (TestCase):
     def stopCaptureStderr(self):
         os.dup2(self.realStderr, 2)
         self.capturedStderr.close()
-        data = open("/tmp/stderr.$$", "rb").read()
+        with open("/tmp/stderr.$$", "rb") as fp:
+            data = fp.read()
         return data
 
     def testLogging(self):
