@@ -4,6 +4,17 @@ from Foundation import *
 from AppKit import *
 import Foundation
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestNSAttributedString (TestCase):
     def testOutput(self):
         self.assertArgIsOut(NSAttributedString.attributesAtIndex_effectiveRange_, 1)
@@ -108,6 +119,8 @@ class TestNSAttributedString (TestCase):
 
     def testMethodsAppKit(self):
         self.assertResultIsBOOL(NSAttributedString.containsAttachments)
+        self.assertArgIsBOOL(NSAttributedString.nextWordFromIndex_forward_, 1)
+        self.assertArgIsOut(NSAttributedString.URLAtIndex_effectiveRange_, 1)
 
         self.assertArgIsOut(NSAttributedString.initWithURL_options_documentAttributes_error_, 2)
         self.assertArgIsOut(NSAttributedString.initWithURL_options_documentAttributes_error_, 3)
@@ -120,6 +133,7 @@ class TestNSAttributedString (TestCase):
         self.assertArgIsOut(NSAttributedString.initWithRTF_documentAttributes_, 1)
         self.assertArgIsOut(NSAttributedString.initWithRTFD_documentAttributes_, 1)
         self.assertArgIsOut(NSAttributedString.initWithHTML_documentAttributes_, 1)
+        self.assertArgIsOut(NSAttributedString.initWithHTML_options_documentAttributes_, 2)
         self.assertArgIsOut(NSAttributedString.initWithHTML_baseURL_documentAttributes_, 2)
         self.assertArgIsOut(NSAttributedString.initWithRTFDFileWrapper_documentAttributes_, 1)
 
@@ -145,6 +159,18 @@ class TestNSAttributedString (TestCase):
         self.assertEqual(NSAttributedStringEnumerationReverse, 1<<1)
         self.assertEqual(NSAttributedStringEnumerationLongestEffectiveRangeNotRequired, 1<<20)
 
+        self.assertIsInstance(NSWritingDirectionAttributeName, unicode)
+        self.assertIsInstance(NSFileTypeDocumentAttribute, unicode)
+        self.assertIsInstance(NSCategoryDocumentAttribute, unicode)
+        self.assertIsInstance(NSFileTypeDocumentOption, unicode)
+
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertIsInstance(NSVerticalGlyphFormAttributeName, unicode)
+        self.assertIsInstance(NSTextLayoutSectionOrientation, unicode)
+        self.assertIsInstance(NSTextLayoutSectionRange, unicode)
+        self.assertIsInstance(NSTextLayoutSectionsAttribute, unicode)
+
     @min_os_level('10.6')
     def testMethods10_6(self):
         self.assertArgHasType(NSAttributedString.enumerateAttributesInRange_options_usingBlock_, 0, NSRange.__typestr__)
