@@ -6,6 +6,17 @@ import sys
 from objc import YES, NO
 from AppKit import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestNSBitmapImageRep(TestCase):
     def testInstantiation(self):
         # widthxheight RGB 24bpp image
@@ -14,10 +25,33 @@ class TestNSBitmapImageRep(TestCase):
         dataPlanes = (None, None, None, None, None)
         dataPlanes = None
         i1 = NSBitmapImageRep.alloc().initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bytesPerRow_bitsPerPixel_(dataPlanes, width, height, 8, 3, NO, NO, NSDeviceRGBColorSpace, 0, 0)
-        self.assert_(i1)
+        self.assertTrue(i1)
 
         i2 = NSBitmapImageRep.alloc().initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bytesPerRow_bitsPerPixel_(None, width, height, 8, 3, NO, NO, NSDeviceRGBColorSpace, 0, 0)
-        self.assert_(i2)
+        self.assertTrue(i2)
+
+    def testPixelFormat(self):
+        width = 16
+        height = 16
+
+        i1 = NSBitmapImageRep.alloc().initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bitmapFormat_bytesPerRow_bitsPerPixel_(None, width, height, 8, 3, NO, NO, NSDeviceRGBColorSpace, NSAlphaFirstBitmapFormat, 0, 0)
+        self.assertIsInstance(i1, NSBitmapImageRep)
+
+        singlePlane = objc.allocateBuffer(width*height*4)
+        for i in range(0, width*height):
+            si = i * 4
+            singlePlane[si] = 1
+            singlePlane[si+1] = 2
+            singlePlane[si+2] = 3
+            singlePlane[si+3] = 4
+        dataPlanes = (singlePlane, None, None, None, None)
+        # test non-planar, premade buffer
+        i2 = NSBitmapImageRep.alloc().initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bitmapFormat_bytesPerRow_bitsPerPixel_(dataPlanes, width, height, 8, 3, NO, NO, NSDeviceRGBColorSpace, NSAlphaFirstBitmapFormat, 0, 0)
+        self.assertIsInstance(i2, NSBitmapImageRep)
+
+        bitmapData = i2.bitmapData()
+
+        self.assertEqual(len(bitmapData), width * height * 4)
 
     def testImageData(self):
         width = 256
@@ -43,14 +77,24 @@ class TestNSBitmapImageRep(TestCase):
 
         # test planar, pre-made buffer
         i1 = NSBitmapImageRep.alloc().initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bytesPerRow_bitsPerPixel_(dataPlanes, width, height, 8, 3, NO, YES, NSDeviceRGBColorSpace, 0, 0)
-        self.assert_(i1)
+        self.assertTrue(i1)
 
         singlePlane = objc.allocateBuffer(width*height*3)
-        for i in range(0, 256*256):
+        for i in range(0, width*height):
             si = i * 3
-            singlePlane[si] = rPlane[i]
-            singlePlane[si+1] = gPlane[i]
-            singlePlane[si+2] = bPlane[i]
+            if sys.version_info[0] == 2:
+                singlePlane[si] = rPlane[i]
+                singlePlane[si+1] = gPlane[i]
+                singlePlane[si+2] = bPlane[i]
+            else:
+                def as_byte(v):
+                    if isinstance(v, int):
+                        return v
+                    else:
+                        return ord(v)
+                singlePlane[si] = as_byte(rPlane[i])
+                singlePlane[si+1] = as_byte(gPlane[i])
+                singlePlane[si+2] = as_byte(bPlane[i])
 
         dataPlanes = (singlePlane, None, None, None, None)
         # test non-planar, premade buffer
@@ -66,11 +110,11 @@ class TestNSBitmapImageRep(TestCase):
         i3 = NSBitmapImageRep.alloc().initWithBitmapDataPlanes_pixelsWide_pixelsHigh_bitsPerSample_samplesPerPixel_hasAlpha_isPlanar_colorSpaceName_bytesPerRow_bitsPerPixel_(None, width, height, 8, 3, NO, YES, NSDeviceRGBColorSpace, 0, 0)
 
         r,g,b,a,o = i3.getBitmapDataPlanes_()
-        self.assert_(r)
-        self.assert_(g)
-        self.assert_(b)
-        self.assert_(not a)
-        self.assert_(not o)
+        self.assertTrue(r)
+        self.assertTrue(g)
+        self.assertTrue(b)
+        self.assertTrue(not a)
+        self.assertTrue(not o)
 
         self.assertEqual(len(r), len(rPlane))
         self.assertEqual(len(g), len(gPlane))
@@ -81,13 +125,21 @@ class TestNSBitmapImageRep(TestCase):
         b[0:len(b)] = bPlane[0:len(bPlane)]
 
         bitmapData = i2.bitmapData()
+
         self.assertEqual(len(bitmapData), len(singlePlane))
-        self.assertEqual(bitmapData, singlePlane)
+        try:
+            memoryview
+        except NameError:
+            self.assertEqual(bitmapData, singlePlane)
+        else:
+            self.assertEqual(bitmapData.tobytes(),
+                singlePlane)
         
         a = array.array('L', [255]*4)
         self.assertArgIsOut(NSBitmapImageRep.getPixel_atX_y_, 0)
         d = i2.getPixel_atX_y_(a, 1, 1)
         self.assertIs(a, d)
+
 class TestBadCreation(TestCase):
 
     # Redirect stderr to /dev/null for the duration of this test, 
@@ -172,8 +224,6 @@ class TestBadCreation(TestCase):
         self.assertArgIsOut(NSBitmapImageRep.getCompression_factor_, 0)
         self.assertArgIsOut(NSBitmapImageRep.getCompression_factor_, 1)
 
-        self.fail("- (id)initWithBitmapDataPlanes:(unsigned char **)planes pixelsWide:(NSInteger)width pixelsHigh:(NSInteger)height bitsPerSample:(NSInteger)bps samplesPerPixel:(NSInteger)spp hasAlpha:(BOOL)alpha isPlanar:(BOOL)isPlanar colorSpaceName:(NSString *)colorSpaceName  bitmapFormat:(NSBitmapFormat)bitmapFormat bytesPerRow:(NSInteger)rBytes bitsPerPixel:(NSInteger)pBits;")
-
 
 
 if __name__ == '__main__':
