@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSBrowserHelper (NSObject):
     def browser_selectCellWithString_inColumn_(self, b, c, s): return 1
     def browser_selectRow_inColumn_(self, b, r, c): return 1
@@ -17,6 +22,7 @@ class TestNSBrowserHelper (NSObject):
     def browser_shouldEditItem_(self, b, i): return 1
     def browser_numberOfRowsInColumn_(self, b, c): return 1
     def browser_createRowsForColumn_inMatrix_(self, b, c, m): return 1
+    def browser_selectionIndexesForProposedSelection_inColumn_(self, b, s, c): return 1
 
 class TestNSBrowser (TestCase):
     def testConstants(self):
@@ -35,6 +41,7 @@ class TestNSBrowser (TestCase):
     def testMethods(self):
         self.assertResultIsBOOL(NSBrowser.isLoaded)
         self.assertResultIsBOOL(NSBrowser.reusesColumns)
+        self.assertArgIsBOOL(NSBrowser.setReusesColumns_, 0)
         self.assertResultIsBOOL(NSBrowser.hasHorizontalScroller)
         self.assertArgIsBOOL(NSBrowser.setHasHorizontalScroller_, 0)
         self.assertResultIsBOOL(NSBrowser.separatesColumns)
@@ -84,6 +91,8 @@ class TestNSBrowser (TestCase):
         self.assertArgIsOut(NSBrowser.getRow_column_forPoint_, 1)
         self.assertArgIsBOOL(NSBrowser.editItemAtIndexPath_withEvent_select_, 2)
 
+        self.assertArgHasType(TestNSBrowserHelper.browser_selectionIndexesForProposedSelection_inColumn_, 2, objc._C_NSInteger)
+
     @min_os_level('10.6')
     def testDelegate10_6(self):
         self.assertResultIsBOOL(TestNSBrowserHelper.browser_isLeafItem_)
