@@ -15,7 +15,7 @@ class TestNSByteOrder (TestCase):
         self.assertEqual(NSSwapShort(350), CFSwapInt16(350))
         self.assertEqual(NSSwapInt(350), CFSwapInt32(350))
         
-        if sys.maxint > 2 ** 32:
+        if sys.maxsize > 2 ** 32:
             self.assertEqual(NSSwapLong(350), CFSwapInt64(350))
             self.assertEqual(NSSwapBigLongToHost(350), CFSwapInt64BigToHost(350))
             self.assertEqual(NSSwapHostLongToBig(350), CFSwapInt64HostToBig(350))
@@ -74,5 +74,6 @@ class TestNSByteOrder (TestCase):
         self.assertIsInstance(v, NSSwappedFloat)
         v = NSSwapHostFloatToLittle(55.0)
         self.assertIsInstance(v, NSSwappedFloat)
+
 if __name__ == "__main__":
     main()
