@@ -2,6 +2,7 @@ from PyObjCTools.TestSupport import *
 import objc
 
 from Foundation import *
+import Foundation
 from PyObjCTest.testhelper import PyObjC_TestClass4
 
 try:
@@ -41,12 +42,12 @@ class TestNSCoderUsage(TestCase):
         newObj = archiver.decodeObject()
 
         self.assertEqual(newObj.intVal, 2)
-        self.assertAlmostEquals(newObj.dblVal, 2.0)
+        self.assertAlmostEqual(newObj.dblVal, 2.0)
         self.assertEqual(len(newObj.dblArray), 4)
-        self.assertAlmostEquals(newObj.dblArray[0], 1.0)
-        self.assertAlmostEquals(newObj.dblArray[1], 2.0)
-        self.assertAlmostEquals(newObj.dblArray[2], 3.0)
-        self.assertAlmostEquals(newObj.dblArray[3], 4.0)
+        self.assertAlmostEqual(newObj.dblArray[0], 1.0)
+        self.assertAlmostEqual(newObj.dblArray[1], 2.0)
+        self.assertAlmostEqual(newObj.dblArray[2], 3.0)
+        self.assertAlmostEqual(newObj.dblArray[3], 4.0)
         self.assertEqual(newObj.decodedBytes[0], b"hello")
         self.assertEqual(newObj.decodedBytes[1], 5)
 
@@ -125,6 +126,11 @@ class TestPythonCoder(TestCase):
         self.assertResultSizeInArg(NSCoder.decodeBytesForKey_returnedLength_, 1)
         self.assertArgIsOut(NSCoder.decodeBytesForKey_returnedLength_, 1)
 
+        self.assertTrue(hasattr(Foundation, 'NXReadNSObjectFromCoder'))
+
+    @min_os_level('10.8')
+    def testMethods10_8(self):
+        self.assertResultIsBOOL(NSCoder.requiresSecureCoding)
 
 if __name__ == '__main__':
     main( )
