@@ -6,20 +6,35 @@ import sys
 from Foundation import *
 from PyObjCTest.testhelper import PyObjC_TestClass3
 
-rawBytes = b"a\x13b\x00cd\xFFef\xEFgh"
-otherBytes = array.array('b')
-otherBytes.fromstring('12345678901234567890' * 5)
 
 if sys.version_info[0] == 3:
     buffer = memoryview
+    def array_frombytes(a, b):
+        return a.frombytes(b)
+
+    def array_tobytes(a):
+        return a.tobytes()
+
+else:
+    def array_frombytes(a, b):
+        return a.fromstring(b)
+
+    def array_tobytes(a):
+        return a.tostring()
 
 try:
     memoryview
 except NameError:
     memoryview = None
 
+
+rawBytes = b"a\x13b\x00cd\xFFef\xEFgh"
+otherBytes = array.array('B')
+array_frombytes(otherBytes, b'12345678901234567890' * 5)
+
 class TestNSData(TestCase):
     def testMethods(self):
+        self.assertResultIsBOOL(NSData.isEqualToData_)
         self.assertResultIsBOOL(NSData.writeToFile_atomically_)
         self.assertArgIsBOOL(NSData.writeToFile_atomically_, 1)
         self.assertResultIsBOOL(NSData.writeToURL_atomically_)
@@ -47,6 +62,14 @@ class TestNSData(TestCase):
         self.assertEqual(NSDataSearchBackwards, 1<<0)
         self.assertEqual(NSDataSearchAnchored, 1<<1)
 
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertEqual(NSDataReadingMappedAlways, 1<<3)
+
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertEqual(NSDataWritingWithoutOverwriting, 1<<1)
+
     @min_os_level('10.6')
     def testMethods10_6(self):
         self.assertResultHasType(NSData.rangeOfData_options_range_, NSRange.__typestr__)
@@ -99,11 +122,15 @@ class TestNSData(TestCase):
         bytesValue = data.bytes()
         self.assertEqual(len(bytesValue), len(rawBytes), "bytes() and rawBytes not equal length.")
 
-        self.assertEquals(rawBytes, bytesValue)
+        if sys.version_info[:2] <= (2,6):
+            self.assertEqual(buffer(rawBytes), bytesValue)
+
+        else:
+            self.assertEqual(rawBytes, bytesValue)
 
         try:
             bytesValue[3] = b'\xAE'
-        except TypeError, r:
+        except TypeError as r:
             if str(r).find('buffer is read-only') == 0:
                 pass
             elif str(r).find('cannot modify read-only memory') == 0:
@@ -116,16 +143,21 @@ class TestNSData(TestCase):
         mutableData = NSMutableData.dataWithBytes_length_(rawBytes, len(rawBytes))
         mutableBytes = mutableData.mutableBytes()
         for i in range(0, len(mutableBytes)):
-            mutableBytes[i] = otherBytes[i:i+1].tostring()
-        mutableBytes[1:8] = otherBytes[1:8].tostring()
+            if sys.version_info[:2] >= (3,3):
+                mutableBytes[i] = array_tobytes(otherBytes[i:i+1])[0]
+            else:
+                mutableBytes[i] = array_tobytes(otherBytes[i:i+1])
+        mutableBytes[1:8] = array_tobytes(otherBytes[1:8])
 
         try:
-            mutableBytes[2:10] = otherBytes[1:5].tostring()
-        except (TypeError, ValueError), r:
+            mutableBytes[2:10] = array_tobytes(otherBytes[1:5])
+        except (TypeError, ValueError) as r:
             if str(r).find('right operand length must match slice length') == 0:
                 pass
             elif 'cannot modify size of memoryview object' in str(r):
                 pass
+            elif 'ndarray assignment: lvalue and rvalue have different structures' in str(r):
+                pass
             else:
                 raise
 
@@ -133,7 +165,7 @@ class TestNSData(TestCase):
         # Test data of different lengths.
         #
         # Data of different lengths may be stored in different subclasses within the class cluster.
-        testFactor = range(1, 64) + [ 1000, 10000, 1000000]
+        testFactor = list(range(1, 64)) + [ 1000, 10000, 1000000]
         for aFactor in testFactor:
             bigRawBytes = b"1234567890" * aFactor
 
@@ -170,6 +202,7 @@ class TestNSData(TestCase):
                 url, 0, None)
         self.assertIs(b2, None)
         self.assertIsInstance(err, NSError)
+
 class MyData (NSData):
     def dataWithBytes_length_(self, bytes, length):
         return ("data", bytes, length)
@@ -215,7 +248,7 @@ class MyData5(NSData):
         return self
 
     def bytes(self):
-        raise ValueError, "No bytes available"
+        raise ValueError("No bytes available")
 
     def length(self):
         return -1
@@ -261,10 +294,10 @@ class TestBuffer(TestCase):
     def testArray(self):
         a = array.array('b', b'foo')
         m = NSMutableData.dataWithData_(a)
-        self.assertEqual(a.tostring(), m[:])
-        self.assert_(objc.repythonify(a) is a)
-        a.fromstring(m)
-        self.assertEqual(a.tostring(), b'foofoo')
+        self.assertEqual(array_tobytes(a), m[:])
+        self.assertTrue(objc.repythonify(a) is a)
+        array_frombytes(a, m)
+        self.assertEqual(array_tobytes(a), b'foofoo')
         m.appendData_(a)
         self.assertEqual(m[:], b'foofoofoo')
         m[3:6] = b'bar'
@@ -277,11 +310,21 @@ class TestBuffer(TestCase):
             b = buffer('foo')
         m = NSMutableData.dataWithData_(b)
         self.assertEqual(b[:], m[:])
-        self.assert_(objc.repythonify(b) is b)
+        self.assertTrue(objc.repythonify(b) is b)
         self.assertEqual(buffer(m)[:], m[:])
 
 
+class TestRegressions (TestCase):
+    def testDataStr(self):
+        if sys.version_info[0] == 2:
+            input = buffer("hello")
+            input_str = "hello"
+        else:
+            input = b"hello"
+            input_str = str(input)
 
+        buf = NSData.dataWithData_(input)
+        self.assertEqual(str(buf), input_str)
 
 
 if __name__ == '__main__':
