@@ -1,6 +1,11 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
+try:
+    unichr
+except NameError:
+    unichr = chr
+
 class TestNSEvent (TestCase):
     def testConstants(self):
         self.assertEqual(NSLeftMouseDown, 1)
@@ -49,7 +54,7 @@ class TestNSEvent (TestCase):
         self.assertEqual(NSOtherMouseDownMask, 1 << NSOtherMouseDown)
         self.assertEqual(NSOtherMouseUpMask, 1 << NSOtherMouseUp)
         self.assertEqual(NSOtherMouseDraggedMask, 1 << NSOtherMouseDragged)
-        self.assertEqual(NSAnyEventMask, -1)
+        self.assertEqual(NSAnyEventMask, NSUIntegerMax)
 
         self.assertEqual(NSAlphaShiftKeyMask, 1 << 16)
         self.assertEqual(NSShiftKeyMask, 1 << 17)
@@ -59,7 +64,7 @@ class TestNSEvent (TestCase):
         self.assertEqual(NSNumericPadKeyMask, 1 << 21)
         self.assertEqual(NSHelpKeyMask, 1 << 22)
         self.assertEqual(NSFunctionKeyMask, 1 << 23)
-        self.assertEqual(NSDeviceIndependentModifierFlagsMask, -65536)
+        self.assertEqual(NSDeviceIndependentModifierFlagsMask, 0xffff0000)
         self.assertEqual(NSUnknownPointingDevice, 0)
         self.assertEqual(NSPenPointingDevice, 1)
         self.assertEqual(NSCursorPointingDevice, 2)
@@ -168,7 +173,28 @@ class TestNSEvent (TestCase):
         self.assertEqual(NSEventMaskBeginGesture, 1 << 19)
         self.assertEqual(NSEventMaskEndGesture, 1 << 20)
 
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertEqual(NSEventPhaseNone, 0)
+        self.assertEqual(NSEventPhaseBegan, 1)
+        self.assertEqual(NSEventPhaseStationary, 2)
+        self.assertEqual(NSEventPhaseChanged, 4)
+        self.assertEqual(NSEventPhaseEnded, 8)
+        self.assertEqual(NSEventPhaseCancelled, 16)
+        self.assertEqual(NSEventPhaseMayBegin, 32)
 
+        self.assertEqual(NSEventGestureAxisNone, 0)
+        self.assertEqual(NSEventGestureAxisHorizontal, 1)
+        self.assertEqual(NSEventGestureAxisVertical, 2)
+
+        self.assertEqual(NSEventSwipeTrackingLockDirection, 1)
+        self.assertEqual(NSEventSwipeTrackingClampGestureAmount, 2)
+
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertEqual(NSEventTypeSmartMagnify, 32)
+        self.assertEqual(NSEventTypeQuickLook, 33)
+        self.assertEqual(NSEventMaskSmartMagnify, 1<<32)
 
     def testFunctions(self):
         v = NSEventMaskFromType(NSLeftMouseDown)
@@ -197,5 +223,13 @@ class TestNSEvent (TestCase):
         self.assertArgIsBlock(NSEvent.addGlobalMonitorForEventsMatchingMask_handler_, 1, b'v@')
         self.assertArgIsBlock(NSEvent.addLocalMonitorForEventsMatchingMask_handler_, 1, b'v@')
 
+    @min_os_level('10.7')
+    def testMethods10_7(self):
+        self.assertResultIsBOOL(NSEvent.hasPreciseScrollingDeltas)
+        self.assertResultIsBOOL(NSEvent.isDirectionInvertedFromDevice)
+        self.assertResultIsBOOL(NSEvent.isSwipeTrackingFromScrollEventsEnabled)
+
+        self.assertArgIsBlock(NSEvent.trackSwipeEventWithOptions_dampenAmountThresholdMin_max_usingHandler_, 3, b'v' + objc._C_CGFloat + objc._C_NSUInteger + objc._C_NSBOOL + b'o^' + objc._C_NSBOOL)
+
 if __name__ == "__main__":
     main()
