@@ -6,6 +6,17 @@ from AppKit import *
 
 import os
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestNSFont(TestCase):
     def matrixEquals(self, value1, value2):
         self.assertEqual(len(value1), len(value2))
@@ -96,7 +107,9 @@ class TestNSFont(TestCase):
 
 
 
-
+    @min_os_level('10.7')
+    def testMethods10_7(self):
+        self.assertResultIsBOOL(NSFont.isVertical)
 
     def testMethods(self):
         self.assertResultIsBOOL(NSFont.isFixedPitch)
