@@ -2,6 +2,17 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestNSGraphics (TestCase):
     def testConstants(self):
         self.assertEqual(NSCompositeClear, 0)
