@@ -4,6 +4,11 @@ from PyObjCTools.TestSupport import *
 
 from Foundation import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSKeyValueCodingHelper (NSObject):
     def validateValue_forKey_error_(self, a, b, c): return 1
     def validateValue_forKeyPath_error_(self, a, b, c): return 1
@@ -24,6 +29,7 @@ class TestNSKeyValueCoding (TestCase):
         self.assertIsInstance(NSUnionOfArraysKeyValueOperator, unicode)
         self.assertIsInstance(NSUnionOfObjectsKeyValueOperator, unicode)
         self.assertIsInstance(NSUnionOfSetsKeyValueOperator, unicode)
+
     def testDefineValidation(self):
         o = NSObject.alloc().init()
 
@@ -40,6 +46,8 @@ class TestNSKeyValueCoding (TestCase):
         self.assertResultIsBOOL(TestNSKeyValueCodingHelper.validateValue_forKey_error_)
         self.assertArgIsOut(TestNSKeyValueCodingHelper.validateValue_forKey_error_, 2)
         self.assertResultIsBOOL(TestNSKeyValueCodingHelper.validateValue_forKeyPath_error_)
+
+        self.assertArgIsInOut(TestNSKeyValueCodingHelper.validateValue_forKeyPath_error_, 0)
         self.assertArgIsOut(TestNSKeyValueCodingHelper.validateValue_forKeyPath_error_, 2)
         self.assertResultIsBOOL(TestNSKeyValueCodingHelper.useStoredAccessor)
 
