@@ -2,6 +2,12 @@
 from PyObjCTools.TestSupport import *
 from AppKit import *
 
+try:
+    long
+except NameError:
+    long = int
+
+
 class TestNSLayoutManagerHelper (NSObject):
     def layoutManager_shouldUseTemporaryAttributes_forDrawingToScreen_atCharacterIndex_effectiveRange_(self, a, b, c, d, e): return 1
     def layoutManager_didCompleteLayoutForTextContainer_atEnd_(self, a, b, c): return 1
@@ -116,6 +122,14 @@ class TestNSLayoutManager (TestCase):
         self.assertArgSizeInArg(NSLayoutManager.fillBackgroundRectArray_count_forCharacterRange_color_, 0, 1)
         self.assertArgHasType(NSLayoutManager.fillBackgroundRectArray_count_forCharacterRange_color_,
                 2, NSRange.__typestr__)
+    
+    @min_os_level('10.7')
+    def testMethods10_7(self):
+        self.assertArgIsIn(NSLayoutManager.showCGGlyphs_positions_count_font_matrix_attributes_inContext_, 0)
+        self.assertArgSizeInArg(NSLayoutManager.showCGGlyphs_positions_count_font_matrix_attributes_inContext_, 0, 2)
+        self.assertArgIsIn(NSLayoutManager.showCGGlyphs_positions_count_font_matrix_attributes_inContext_, 1)
+        self.assertArgSizeInArg(NSLayoutManager.showCGGlyphs_positions_count_font_matrix_attributes_inContext_, 1, 2)
+
 
 
 
