@@ -2,6 +2,17 @@ from PyObjCTools.TestSupport import *
 import sys
 from Foundation import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 
 class TestNSObjCRuntime (TestCase):
     def testConstants(self):
@@ -43,12 +54,28 @@ class TestNSObjCRuntime (TestCase):
         self.assertEqual(NSFoundationVersionNumber10_4_9, 567.29)
         self.assertEqual(NSFoundationVersionNumber10_4_10,        567.29)
         self.assertEqual(NSFoundationVersionNumber10_4_11,        567.36)
+        self.assertEqual( NSFoundationVersionNumber10_5, 677.00)
+        self.assertEqual( NSFoundationVersionNumber10_5_1, 677.10)
+        self.assertEqual( NSFoundationVersionNumber10_5_2, 677.15)
+        self.assertEqual( NSFoundationVersionNumber10_5_3, 677.19)
+        self.assertEqual( NSFoundationVersionNumber10_5_4, 677.19)
+        self.assertEqual( NSFoundationVersionNumber10_5_5, 677.21)
+        self.assertEqual( NSFoundationVersionNumber10_5_6, 677.22)
+        self.assertEqual( NSFoundationVersionNumber10_5_7, 677.24)
+        self.assertEqual( NSFoundationVersionNumber10_5_8, 677.26)
+        self.assertEqual( NSFoundationVersionNumber10_6, 751.00)
+        self.assertEqual( NSFoundationVersionNumber10_6_1, 751.00)
+        self.assertEqual( NSFoundationVersionNumber10_6_2, 751.14)
+        self.assertEqual( NSFoundationVersionNumber10_6_3, 751.21)
+        self.assertEqual( NSFoundationVersionNumber10_6_4, 751.29)
+        self.assertEqual( NSFoundationVersionNumber10_6_5, 751.42)
+
 
         self.assertIsInstance(NSFoundationVersionNumber, float)
         self.assertIsInstance(NSIntegerMax, (int, long))
         self.assertIsInstance(NSIntegerMin, (int, long))
         self.assertIsInstance(NSUIntegerMax, (int, long))
-        if sys.maxint > 2 ** 32:
+        if sys.maxsize > 2 ** 32:
             self.assertEqual(NSIntegerMax, 2 ** 63 -1)
             self.assertEqual(NSIntegerMin, -(2 ** 63))
             self.assertEqual(NSUIntegerMax, 2**64-1)
@@ -82,14 +109,20 @@ class TestNSObjCRuntime (TestCase):
         self.assertEqual(NSSortConcurrent, 1<<0)
         self.assertEqual(NSSortStable, 1<<4)
 
-
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertEqual(NSFoundationVersionNumber10_7, 833.10)
+        self.assertEqual(NSFoundationVersionNumber10_7_1, 833.10)
+        self.assertEqual(NSFoundationVersionNumber10_7_2, 833.20)
+        self.assertEqual(NSFoundationVersionNumber10_7_3, 833.24)
+        self.assertEqual(NSFoundationVersionNumber10_7_4, 833.25)
 
     def testSelectorAccess(self):
         v = NSStringFromSelector('description')
         self.assertIsInstance(v, unicode)
         self.assertEqual(v, 'description')
 
-        v = NSSelectorFromString(u"description")
+        v = NSSelectorFromString(b"description".decode('ascii'))
         self.assertIsInstance(v, str)
         self.assertEqual(v, 'description')
 
@@ -123,5 +156,8 @@ class TestNSObjCRuntime (TestCase):
         self.assertEqual(ABS(-1), 1)
         self.assertEqual(ABS(-1.0), 1.0)
 
+    def testFunctions(self):
+        self.assertArgIsPrintf(NSLog, 0)
+
 if __name__ == "__main__":
     main()
