@@ -3,6 +3,11 @@ from PyObjCTools.TestSupport import *
 from objc import *
 from Foundation import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSPathUtilities(TestCase):
     def testSearchPaths(self):
         self.assert_( 
@@ -34,6 +39,7 @@ class TestNSPathUtilities(TestCase):
         self.assertIsInstance(s, unicode)
         s = NSOpenStepRootDirectory()
         self.assertIsInstance(s, unicode)
+
     def testConstants(self):
         self.assertEqual(NSApplicationDirectory, 1)
         self.assertEqual(NSDemoApplicationDirectory, 2)
@@ -71,6 +77,11 @@ class TestNSPathUtilities(TestCase):
         self.assertEqual(NSPreferencePanesDirectory, 22)
         self.assertEqual(NSItemReplacementDirectory, 99)
 
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertEqual(NSApplicationScriptsDirectory, 23)
+        self.assertEqual(NSTrashDirectory, 102)
+
     def testMethods(self):
         self.assertResultIsBOOL(NSString.isAbsolutePath)
         self.assertArgIsOut(NSString.completePathIntoString_caseSensitive_matchesIntoArray_filterTypes_, 0)
