@@ -20,11 +20,19 @@ class TestNSPointerFunctions (TestCase):
 
         self.assertEqual(NSPointerFunctionsCopyIn, (1 << 16))
 
+    @min_os_level('10.8')
+    def testConstants10_8(self):
+        self.assertEqual(NSPointerFunctionsWeakMemory, 5<<0)
+
     def testPropType(self):
         o = NSPointerFunctions.alloc().initWithOptions_(0)
 
         v = o.usesStrongWriteBarrier()
         self.assertTrue((v is True) or (v is False) )
+
+        self.assertArgIsBOOL(o.setUsesStrongWriteBarrier_, 0)
+        self.assertArgIsBOOL(o.setUsesWeakReadAndWriteBarriers_, 0)
+
         v = o.usesWeakReadAndWriteBarriers()
         self.assertTrue((v is True) or (v is False) )
 
