@@ -1,12 +1,24 @@
 from Foundation import *
 from PyObjCTools.TestSupport import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 
 class TestNSRange (TestCase):
     def testStructs(self):
         v = NSRange()
         self.assertHasAttr(v, 'location')
         self.assertHasAttr(v, 'length')
+
     def testFunctions(self):
         v = NSMakeRange(1, 4)
         self.assertIsInstance(v, NSRange)
@@ -34,6 +46,8 @@ class TestNSRange (TestCase):
         self.assertIsInstance(w, NSRange)
         self.assertEqual(w, (9, 10))
 
+        self.assertResultHasType(NSValue.rangeValue, NSRange.__typestr__)
+
 if __name__ == "__main__":
     main()
 
