@@ -1,6 +1,11 @@
 from PyObjCTools.TestSupport import *
 from Foundation import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSStreamHelper (NSObject):
     def stream_handleEvent_(self, a, b): pass
 
@@ -11,7 +16,7 @@ class TestNSStreamUsage(TestCase):
 
         # Try to create a connection to the IPP port on the local host
         inputStream, outputStream = NSStream.getStreamsToHost_port_inputStream_outputStream_(
-                NSHost.hostWithAddress_(u"127.0.0.1"), 
+                NSHost.hostWithAddress_(b"127.0.0.1".decode('ascii')), 
                 631, # IPP port
                 None,
                 None
@@ -59,6 +64,14 @@ class TestNSStreamUsage(TestCase):
         self.assertIsInstance(NSStreamSocketSSLErrorDomain, unicode)
         self.assertIsInstance(NSStreamSOCKSErrorDomain, unicode)
 
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertIsInstance(NSStreamNetworkServiceType, unicode)
+        self.assertIsInstance(NSStreamNetworkServiceTypeVoIP, unicode)
+        self.assertIsInstance(NSStreamNetworkServiceTypeVideo, unicode)
+        self.assertIsInstance(NSStreamNetworkServiceTypeBackground, unicode)
+        self.assertIsInstance(NSStreamNetworkServiceTypeVoice, unicode)
+
     def testMethods(self):
         self.assertResultIsBOOL(NSStream.setProperty_forKey_)
 
