@@ -4,7 +4,13 @@ from Foundation import *
 
 # HACK
 import Foundation
-NSZonePtr = getattr(Foundation, 'NSZone*')
+#NSZonePtr = getattr(Foundation, 'NSZone*')
+
+try:
+    long
+except NameError:
+    long = int
+
 
 class TestNSZone (TestCase):
     def testWithZones(self):
@@ -33,6 +39,7 @@ class TestNSZone (TestCase):
         self.assertNotHasAttr(Foundation, 'NSAllocateMemoryPages')
         self.assertNotHasAttr(Foundation, 'NSDeallocateMemoryPages')
         self.assertNotHasAttr(Foundation, 'NSCopyMemoryPages')
+
     def testConstants(self):
         self.assertEqual(NSScannedOption, (1<<0))
         self.assertEqual(NSCollectorDisabledOption, (1<<1))
@@ -46,6 +53,7 @@ class TestNSZone (TestCase):
         self.assertIs(v, o)
         v = NSMakeCollectable(None)
         self.assertIs(v, None)
+
     def testInfoFunctions(self):
         v = NSPageSize()
         self.assertIsInstance(v, (int, long))
@@ -57,15 +65,16 @@ class TestNSZone (TestCase):
         self.assertIsInstance(v, (int, long))
         v = NSRealMemoryAvailable()
         self.assertIsInstance(v, (int, long))
+
     def testZoneCreation(self):
         z = NSDefaultMallocZone()
         if z is not None:
             self.assertIsInstance(z, NSZonePtr)
         z = NSCreateZone(5000, 100, True)
         self.assertIsInstance(z, NSZonePtr)
-        NSSetZoneName(z, u"Hello World")
+        NSSetZoneName(z, b"Hello World".decode('ascii'))
         nm = NSZoneName(z)
-        self.assertEqual(nm, u"Hello World")
+        self.assertEqual(nm, b"Hello World".decode('ascii'))
 
         NSRecycleZone(z); z = None
 
